<?php
/**
 * @package     Reporter for VirtueMart
 * 
 * @copyright   Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Abhishek Das <info@virtueplanet.com> - https://www.virtueplanet.com
 */

defined('_JEXEC') or die();

/**
 * Reporter for VirtueMart Component Package Script
 * 
 * @since   2.1
 */
class pkg_vmreporterInstallerScript
{
	/**
	 * Called on installation
	 *
	 * @param   JAdapterInstance  $adapter  The object responsible for running this script
	 *
	 * @return  boolean  True on success
	 */
	public function install($adapter)
	{
		$app = JFactory::getApplication();
		
		if ($this->enablePlugins(true))
		{
			$pluginsUrl = JRoute::_('index.php?option=com_plugins&view=plugins&filter_folder=vmreporter&filter[folder]=vmreporter');
			
			$message  = 'Reporter for VirtueMart component package has been successfully installed on your site. ';
			$message .= '<a href="' . $pluginsUrl . '">Click here</a> to enable additional plugins.';
			
			$app->enqueueMessage($message);
		}
		
		return true;
	}

	/**
	 * Called on update
	 *
	 * @param   JAdapterInstance  $adapter  The object responsible for running this script
	 *
	 * @return  boolean  True on success
	 */
	public function update($adapter)
	{
		$app = JFactory::getApplication();
		
		if ($this->enablePlugins())
		{
			$pluginsUrl = JRoute::_('index.php?option=com_plugins&view=plugins&filter_folder=vmreporter&filter[folder]=vmreporter');
			
			$message  = 'Reporter for VirtueMart component package has been successfully updated on your site. ';
			$message .= '<a href="' . $pluginsUrl . '">Click here</a> to enable additional plugins.';
			
			$app->enqueueMessage($message);
		}
		
		return true;
	}

	/**
	 * Called before any type of action
	 *
	 * @param     string              $route      Which action is happening (install|uninstall|discover_install)
	 * @param     jadapterinstance    $adapter    The object responsible for running this script
	 *
	 * @return    boolean                         True on success
	 */
	public function preflight($route, $adapter)
	{
		return true;
	}


	/**
	 * Called after any type of action
	 *
	 * @param     string              $route      Which action is happening (install|uninstall|discover_install)
	 * @param     jadapterinstance    $adapter    The object responsible for running this script
	 *
	 * @return    boolean                         True on success
	 */
	public function postflight($route, $adapter)
	{
		return true;
	}
	
	/**
	* Private method to enable all required plugins of the component
	* 
	* @return boolean
	*/
	private function enablePlugins($installAdditionalPlugins = false)
	{
		$app             = JFactory::getApplication();
		$systemPlugin    = $this->getPlugin('system', 'vmreporter');
		$plugins         = [];
		$hasSystemPlugin = false;
		
		if ($systemPlugin === false)
		{
			$app->enqueueMessage('Please enable "System - Reporter for VirtueMart" plugin.');
			
			return false;
		}
		
		if (empty($systemPlugin))
		{
			$app->enqueueMessage('Package is not installed correctly. Missing required plugin - "System - Reporter for VirtueMart".');
			
			return false;
		}
		
		if (!$systemPlugin->enabled)
		{
			$plugins[] = $systemPlugin->extension_id;
			
			$hasSystemPlugin = true;
		}
		
		if ($installAdditionalPlugins)
		{
			$invoiceNumberPlugin = $this->getPlugin('vmreporter', 'invoicenumber');
			
			if (!empty($invoiceNumberPlugin) && !$invoiceNumberPlugin->enabled)
			{
				$plugins[] = $invoiceNumberPlugin->extension_id;
			}
		}
		
		if (!empty($plugins))
		{
			jimport('legacy.model.legacy');
			
			JModelLegacy::addIncludePath(JPATH_ADMINISTRATOR . '/components/com_plugins/models/', 'PluginsModel');
			
			$model = JModelLegacy::getInstance('Plugin', 'PluginsModel');
			
			if (!$model && $hasSystemPlugin)
			{
				$app->enqueueMessage('Please enable "System - Reporter for VirtueMart" plugin.');
				
				return false;
			}
			
			if (!$model->publish($plugins, 1) && $hasSystemPlugin)
			{
				$app->enqueueMessage('Please enable "System - Reporter for VirtueMart" plugin.');
				
				return false;
			}
		}

		return true;
	}

	/**
	* Private method to get the installed Reporter for VirtueMart - System plugin id.
	* 
	* @return mixed(boolean/integer)  false if not found.
	*/
	private function getPlugin($folder, $element)
	{
		$db    = JFactory::getDBO();
		$query = $db->getQuery(true);
		
		$query->select($db->quoteName(['extension_id', 'enabled']))
			->from($db->quoteName('#__extensions'))
			->where($db->quoteName('type') . ' = ' . $db->quote('plugin'))
			->where($db->quoteName('element') . ' = ' . $db->quote($element))
			->where($db->quoteName('folder') . ' = ' . $db->quote($folder));
		
		try
		{
			$db->setQuery($query);
			$extension = $db->loadObject();
		}
		catch(Exception $e)
		{
			// We can not throw SQL error here.
			return false;
		}
		
		return $extension;
	}
}
