<?php
/**
 * @package     Reporter for VirtueMart
 * 
 * @copyright   Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Abhishek Das <info@virtueplanet.com> - https://www.virtueplanet.com
 */

defined('_JEXEC') or die;

jimport('joomla.filesystem.file');

/**
 * Frontpage controller class.
 */
class VMReporterControllerFrontPage extends JControllerAdmin
{
	public function download()
	{
		$app = JFactory::getApplication();

		if (!JSession::checkToken('get'))
		{
			$app->enqueueMessage(JText::_('JINVALID_TOKEN'), 'warning');
			$app->redirect(JRoute::_('index.php?option=com_vmreporter&view=frontpage', false));
		}
		
		$model = $this->getModel();
		
		// Load the period.
		$period = $app->getUserStateFromRequest('com_vmreporter.frontpage.filter.period', 'filter_period', 'this_month');
		$model->setState('report.period', $period);
		
		$status = $app->getUserStateFromRequest('com_vmreporter.frontpage.filter.status', 'filter_status', array('C', 'U'), 'ARRAY');
		$model->setState('report.status', $status);
		
		$start_date = $app->getUserStateFromRequest('com_vmreporter.frontpage.filter.start_date', 'filter_start_date', '2015-01-01 00:00:00', 'STRING');
		$model->setState('report.start_date', $start_date);
		
		$end_date = $app->getUserStateFromRequest('com_vmreporter.frontpage.filter.end_date', 'filter_end_date', '2016-01-01 00:00:00', 'STRING');
		$model->setState('report.end_date', $end_date);
		
		$params = JComponentHelper::getParams('com_vmreporter');
		$model->setState('params', $params);
		
		// Get CSV data
		$csv = $model->getCSV(null, null, false);
		
		// Build report file name
		$filename = $params->get('download_filename', 'report') . '.csv';
		$filename = JFile::makeSafe($filename);
		
		// Disable caching
		header('Cache-Control: public,max-age=1,must-revalidate');
		header('Expires: ' . gmdate('D, d M Y H:i:s', ($_SERVER['REQUEST_TIME'] + 1)) . ' GMT');
		header('Last-modified: ' . gmdate('D, d M Y H:i:s', $_SERVER['REQUEST_TIME']) . ' GMT');

		if (function_exists('header_remove')) 
		{
			header_remove('Pragma');
		}
		
		// Force download  
		header('Content-Type: application/force-download');
		header('Content-Type: application/octet-stream');
		header('Content-Type: application/download');

		// Disposition / encoding on response body
		header('Content-Disposition: attachment;filename=' . $filename);
		header('Content-Transfer-Encoding: binary');
		
		echo $csv;
		
		flush();
		$app->close();
	}
	
	/**
	 * Proxy for getModel.
	 */
	public function getModel($name = 'Frontpage', $prefix = 'VMReporterModel', $config = array('ignore_request' => true))
	{
		return parent::getModel($name, $prefix, $config);
	}
}
