<?php
/**
 * @package     Reporter for VirtueMart
 * 
 * @copyright   Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Abhishek Das <info@virtueplanet.com> - http://www.virtueplanet.com
 */

defined('_JEXEC') or die;

/**
 * Report List controller class.
 */
class VMReporterControllerInventory extends JControllerAdmin
{
	/**
	 * Download report task.
	 */
	public function download()
	{
		$app = JFactory::getApplication();

		if (!JSession::checkToken('get'))
		{
			$app->enqueueMessage(JText::_('JINVALID_TOKEN'), 'warning');
			$app->redirect(JRoute::_('index.php?option=com_vmreporter&view=inventory', false));
		}

		$input   = $app->input;
		$model   = $this->getModel();
		$context = 'com_vmreporter.inventory';
		
		// Load the filter state.
		$search = $app->getUserStateFromRequest($context . '.filter.search', 'filter_search');
		$model->setState('filter.search', $search);
		
		$available_stock = $app->getUserStateFromRequest($context . '.filter.available_stock', 'filter_available_stock');
		$model->setState('filter.available_stock', $available_stock);
		
		$published = $app->getUserStateFromRequest($context . '.filter.published', 'filter_published');
		$model->setState('filter.published', $published);
		
		$product_special = $app->getUserStateFromRequest($context . '.filter.product_special', 'filter_product_special');
		$model->setState('filter.product_special', $product_special);
		
		$categories = $app->getUserStateFromRequest($context . '.filter.categories', 'filter_categories');
		$model->setState('filter.categories', $categories);
		
		$manufacturers = $app->getUserStateFromRequest($context . '.filter.manufacturers', 'filter_manufacturers');
		$model->setState('filter.manufacturers', $manufacturers);
		
		$parent_product_id = $app->getUserState($context . '.filter.parent_product_id', 0);
		$model->setState('filter.parent_product_id', $parent_product_id);
		
		$params = JComponentHelper::getParams('com_vmreporter');
		$model->setState('params', $params);
		
		// Get CSV data
		$csv = $model->getCSV(null, null, false);
		
		// Get date
		$date = JFactory::getDate('now', 'UTC');
		
		// Set the correct time zone based on the server configuration.
		$date->setTimezone(new DateTimeZone(JFactory::getConfig()->get('offset')));
		
		// Build report file name
		$filename = 'inventory_' . $date->format('Y-m-d', true) . '.csv';
		$filename = JFile::makeSafe($filename);
		
		// Disable caching
		header('Cache-Control: public,max-age=1,must-revalidate');
		header('Expires: ' . gmdate('D, d M Y H:i:s', ($_SERVER['REQUEST_TIME'] + 1)) . ' GMT');
		header('Last-modified: ' . gmdate('D, d M Y H:i:s', $_SERVER['REQUEST_TIME']) . ' GMT');

		if (function_exists('header_remove')) 
		{
			header_remove('Pragma');
		}
		
		// Force download  
		header('Content-Type: application/force-download');
		header('Content-Type: application/octet-stream');
		header('Content-Type: application/download');

		// Disposition / encoding on response body
		header('Content-Disposition: attachment;filename=' . $filename);
		header('Content-Transfer-Encoding: binary');
		
		echo $csv;
		
		flush();
		$app->close();
	}
	
	public function reset()
	{
		JSession::checkToken() or die('Invalid Token');
		
		$app = JFactory::getApplication();
		
		$app->setUserState('com_vmreporter.inventory.filter.parent_product_id', 0);
		
		$app->redirect(JRoute::_('index.php?option=com_vmreporter&view=inventory', false));
	}

	/**
	 * Proxy for getModel.
	 */
	public function getModel($name = 'Inventory', $prefix = 'VMReporterModel', $config = ['ignore_request' => true])
	{
		return parent::getModel($name, $prefix, $config);
	}
}