<?php
/**
 * @package     Reporter for VirtueMart
 * 
 * @copyright   Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Abhishek Das <info@virtueplanet.com> - https://www.virtueplanet.com
 */

defined('_JEXEC') or die;

jimport('joomla.filesystem.file');

class VMReporterControllerReport extends JControllerAdmin
{
	/**
	 * Constructor
	 *
	 * @throws Exception
	 */
	public function __construct()
	{
		$this->view_list = 'reports';
		
		parent::__construct();
	}
	
	public function download()
	{
		$app = JFactory::getApplication();

		if (!JSession::checkToken('get'))
		{
			$app->enqueueMessage(JText::_('JINVALID_TOKEN'), 'warning');
			$app->redirect(JRoute::_('index.php?option=com_vmreporter&view=reports', false));
		}
		
		$pk    = $this->input->getInt('id', 0);
		$model = $this->getModel();
		
		$model->setState('report.id', $pk);
		
		$params = JComponentHelper::getParams('com_vmreporter');
		
		$model->setState('params', $params);
		
		// Get CSV data
		$csv = $model->getCSV();
		
		// Get report template
		$template = $model->getReportTemplate();
		
		// Build report file name
		$filename = (!empty($template->download_filename) ? $template->download_filename : $params->get('download_filename', 'report')) . '.csv';
		$filename = JFile::makeSafe($filename);
		
		// disable caching
		header('Cache-Control: public,max-age=1,must-revalidate');
		header('Expires: ' . gmdate('D, d M Y H:i:s', ($_SERVER['REQUEST_TIME'] + 1)) . ' GMT');
		header('Last-modified: ' . gmdate('D, d M Y H:i:s', $_SERVER['REQUEST_TIME']) . ' GMT');

		if (function_exists('header_remove')) 
		{
			header_remove('Pragma');
		}

		// Force download  
		header('Content-Type: application/force-download');
		header('Content-Type: application/octet-stream');
		header('Content-Type: application/download');

		// Disposition / encoding on response body
		header('Content-Disposition: attachment;filename=' . $filename);
		header('Content-Transfer-Encoding: binary');
		
		echo $csv;
		
		$app->close();
	}
	
	/**
	 * Proxy for getModel.
	 */
	public function getModel($name = 'Report', $prefix = 'VMReporterModel', $config = array('ignore_request' => true))
	{
		return parent::getModel($name, $prefix, $config);
	}
}
