<?php
/**
 * @package     Reporter for VirtueMart
 * 
 * @copyright   Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Abhishek Das <info@virtueplanet.com> - https://www.virtueplanet.com
 */

defined('_JEXEC') or die;

/**
 * VMReporter HTML helper
 */
abstract class JHtmlVMReporter
{
	protected static $categories = [];
	
	protected static $manufacturers = [];
	
	public static function template($name, $id, $attribs = '', $selected = '')
	{
		static $templates = null;
		
		if ($templates === null)
		{
			$db    = JFactory::getDbo();
			$query = $db->getQuery(true);
			
			$query->select($db->quoteName('id'))
			      ->select($db->quoteName('name'))
			      ->from($db->quoteName('#__vmreporter_templates'));
			
			$db->setQuery($query);
			$templates = $db->loadObjectList();
		}
		
		$attribs = !empty($attribs) ? ' ' . $attribs : '';
		$options = array();
		
		$options[] = JHtml::_('select.option', 0, JText::_('COM_VMREPORTER_SELECT_TEMPLATE'));
		
		foreach($templates as $template)
		{
			$options[] = JHtml::_('select.option', $template->id, htmlspecialchars($template->name, ENT_COMPAT, 'UTF-8', false));
		}
		
		return JHtml::_('select.genericlist', $options, $name, trim($attribs), 'value', 'text', $selected, $id);
	}
	
	public static function yesno($name, $id, $attribs = '', $selected = '')
	{
		$attribs = !empty($attribs) ? ' ' . $attribs : '';
		$options = array();
		
		$options[] = JHtml::_('select.option', 0, JText::_('JNO'));
		$options[] = JHtml::_('select.option', 1, JText::_('JYES'));
		
		return JHtml::_('select.genericlist', $options, $name, trim($attribs), 'value', 'text', $selected, $id);
	}
	
	public static function email($name, $id, $attribs = '', $value = '', $coreasdefault = true)
	{
		JHtml::_('jquery.framework');
		JHtml::_('script', 'system/html5fallback.js', array('relative' => true, 'version' => 'auto'));
		JHtml::_('vmreporter.script', 'vmreporter/angular.min.js');
		JHtml::_('bootstrap.framework');
		JHtml::_('vmreporter.script', 'vmreporter/typeahead.bundle.js');
		JHtml::_('vmreporter.script', 'vmreporter/bootstrap-tagsinput.js');
		JHtml::_('vmreporter.script', 'vmreporter/bootstrap-tagsinput-angular.js');
		JHtml::_('vmreporter.stylesheet', 'vmreporter/bootstrap-tagsinput.css');
		
		JFactory::getDocument()->addScriptDeclaration("
		jQuery(function($) {
			$('#{$id}').tagsinput({
					trimValue: true,
					allowDuplicates: false,
					tagClass: 'label bg-secondary'
			});
			$('#{$id}').on('beforeItemAdd', function(event) {
				var regex = /^(([^<>()\[\]\.,;:\s@\"]+(\.[^<>()\[\]\.,;:\s@\"]+)*)|(\".+\"))@(([^<>()[\]\.,;:\s@\"]+\.)+[^<>()[\]\.,;:\s@\"]{2,})$/i;
				if (!regex.test(event.item)) {
					alert('Invalid entry. Please enter a valid email address.');
					event.cancel = true;
					return;
				}
			});
		});
		");
		
		if (empty($value) && $coreasdefault)
		{
			$db    = JFactory::getDbo();
			$query = $db->getQuery(true);
			
			$query->select($db->quoteName('email'))
				->from($db->quoteName('#__users'))
				->where($db->quoteName('sendEmail') . ' = 1');

			$db->setQuery($query);
			$emails = $db->loadColumn();
			
			if (!empty($emails))
			{
				$value = implode(',', $emails);
			}
		}
		
		$html  = '<input type="text" name="' . $name . '" id="' . $id . '" value="' . $value . '" ' . $attribs . ' autocomplete="off" />';
		$html .= '<div class="muted text-muted small">Eg: support@example.com, bill@mail.com etc.</div>';
		
		return $html;
	}
	
	public static function orderstatuses($name, $id, $attribs = '', $selected = array())
	{
		static $statuses = null;
		
		if ($statuses === null)
		{
			$db    = JFactory::getDBO();
			$query = $db->getQuery(true);
			
			$query->select($db->quoteName('os.order_status_code') . ' AS value, ' . $db->quoteName('os.order_status_name') . ' AS text')
			      ->from($db->quoteName('#__virtuemart_orderstates') . ' AS os')
			      ->order($db->quoteName('os.virtuemart_orderstate_id') . ' ASC');
			
			try
			{
				$db->setQuery($query);
				$statuses = $db->loadObjectList();
			}
			catch (Exception $e)
			{
				JFactory::getApplication()->enqueueMessage($e->getMessage(), 'error');
				
				return false;
			}
		}
		
		JHtml::_('jquery.framework');
		JHtml::_('vmreporter.stylesheet', 'vmreporter/icons.css');
		
		if (!version_compare(JVERSION, '4.0.0', 'ge'))
		{
			JHtml::_('vmreporter.stylesheet', 'vmreporter/bootstrap-select.min.css');
			JHtml::_('vmreporter.script', 'vmreporter/bootstrap-select.min.js');
			
			JFactory::getDocument()->addScriptDeclaration("
			jQuery(document).ready(function($) {
				$('#{$id}').selectpicker();
			});
			");
		}
		
		$options  = array();
		$attribs  = $attribs . ' multiple="multiple"';
		$selected = $selected ? $selected : -1;
		
		foreach($statuses as $status)
		{
			$options[] = JHtml::_('select.option', $status->value, JText::_($status->text));
		}
		
		$html = JHtml::_('select.genericlist', $options, $name, trim($attribs), 'value', 'text', $selected, $id);
		
		if (version_compare(JVERSION, '4.0.0', 'ge'))
		{
			JText::script('JGLOBAL_SELECT_NO_RESULTS_MATCH');
			JText::script('JGLOBAL_SELECT_PRESS_TO_SELECT');

			JFactory::getApplication()->getDocument()->getWebAssetManager()
			    ->usePreset('choicesjs')
			    ->useScript('webcomponent.field-fancy-select');
			
			$html = '<joomla-field-fancy-select  placeholder="Type or select some options">' . $html . '</joomla-field-fancy-select>';
		}
		
		return $html;
	}
	
	public static function periods($name, $id, $attribs = '', $selected = array())
	{
		JHtml::_('jquery.framework');
		JHtml::_('vmreporter.stylesheet', 'vmreporter/icons.css');
		
		if (!version_compare(JVERSION, '4.0.0', 'ge'))
		{
			JHtml::_('vmreporter.stylesheet', 'vmreporter/bootstrap-select.min.css');
			JHtml::_('vmreporter.script', 'vmreporter/bootstrap-select.min.js');
			
			JFactory::getDocument()->addScriptDeclaration("
			jQuery(document).ready(function($) {
				$('#{$id}').selectpicker();
			});
			");
		};
		
		$options  = array();

		$options[] = JHtml::_('select.option', 'last_month', JText::_('COM_VMREPORTER_PERIOD_LAST_MONTH'));
		$options[] = JHtml::_('select.option', 'last_year', JText::_('COM_VMREPORTER_PERIOD_LAST_YEAR'));
		$options[] = JHtml::_('select.option', 'last_week', JText::_('COM_VMREPORTER_PERIOD_LAST_WEEK'));
		$options[] = JHtml::_('select.option', 'this_month', JText::_('COM_VMREPORTER_PERIOD_THIS_MONTH'));
		$options[] = JHtml::_('select.option', 'this_year', JText::_('COM_VMREPORTER_PERIOD_THIS_YEAR'));
		$options[] = JHtml::_('select.option', 'this_week', JText::_('COM_VMREPORTER_PERIOD_THIS_WEEK'));
		$options[] = JHtml::_('select.option', 'fixed', JText::_('COM_VMREPORTER_PERIOD_FIXED'));

		return JHtml::_('select.genericlist', $options, $name, trim($attribs), 'value', 'text', $selected, $id);
	}
	
	/**
	 * Displays a calendar control field
	 *
	 * @param   string  $value    The date value
	 * @param   string  $name     The name of the text field
	 * @param   string  $id       The id of the text field
	 * @param   string  $format   The date format
	 * @param   mixed   $attribs  Additional HTML attributes
	 *
	 * @return  string  HTML markup for a calendar field
	 */
	public static function calendar($value, $name, $id, $format = '%Y-%m-%d', $attribs = null)
	{
		static $done;
		
		if (version_compare(JVERSION, '3.7.0', 'ge'))
		{
			return JHtml::_('calendar', $value, $name, $id, $format = '%Y-%m-%d', $attribs);
		}
		
		if ($done === null)
		{
			$done = array();
		}

		$readonly = isset($attribs['readonly']) && $attribs['readonly'] == 'readonly';
		$disabled = isset($attribs['disabled']) && $attribs['disabled'] == 'disabled';

		if (is_array($attribs))
		{
			$attribs['class'] = isset($attribs['class']) ? $attribs['class'] : 'input-medium';
			$attribs['class'] = trim($attribs['class'] . ' hasTooltip');

			$attribs = JArrayHelper::toString($attribs);
		}

		JHtml::_('bootstrap.tooltip');

		// Format value when not nulldate ('0000-00-00 00:00:00'), otherwise blank it as it would result in 1970-01-01.
		if ($value && $value != JFactory::getDbo()->getNullDate())
		{
			$tz = date_default_timezone_get();
			date_default_timezone_set('UTC');
			$inputvalue = strftime($format, strtotime($value));
			date_default_timezone_set($tz);
		}
		else
		{
			$inputvalue = '';
		}

		// Load the calendar behavior
		JHtml::_('behavior.calendar');

		// Only display the triggers once for each control.
		if (!in_array($id, $done))
		{
			$document = JFactory::getDocument();
			$document
				->addScriptDeclaration(
				'jQuery(document).ready(function($) {Calendar.setup({
			// Id of the input field
			inputField: "' . $id . '",
			// Format of the input field
			ifFormat: "' . $format . '",
			// Trigger for the calendar (button ID)
			button: "' . $id . '_btn",
			// Alignment (defaults to "Bl")
			align: "Tl",
			singleClick: true,
			firstDay: ' . JFactory::getLanguage()->getFirstDay() . '
			});});'
			);
			$done[] = $id;
		}

		// Hide button using inline styles for readonly/disabled fields
		$btn_style = ($readonly || $disabled) ? ' style="display:none;"' : '';
		$div_class = (!$readonly && !$disabled) ? ' class="input-append"' : '';

		return '<div' . $div_class . '>'
				. '<input type="text" title="' . ($inputvalue ? JHtml::_('date', $value, null, null) : '')
				. '" name="' . $name . '" id="' . $id . '" value="' . htmlspecialchars($inputvalue, ENT_COMPAT, 'UTF-8') . '" ' . $attribs . ' />'
				. '<button type="button" class="btn btn-secondary" id="' . $id . '_btn"' . $btn_style . '><span class="icon-calendar"></span></button>'
			. '</div>';
	}
	
	public static function script($filename, $options = array(), $attribs = array())
	{
		if (version_compare(JVERSION, '3.7.0', 'ge'))
		{
			// JavaScript loading options
			$scriptOptions = array(
			  'framework'     => isset($options['framework']) ? $options['framework'] : false,
			  'relative'      => isset($options['relative']) ? $options['relative'] : true,
			  'pathOnly'      => isset($options['pathOnly']) ? $options['pathOnly'] : false,
			  'detectBrowser' => isset($options['detectBrowser']) ? $options['detectBrowser'] : true,
			  'detectDebug'   => isset($options['detectDebug']) ? $options['detectDebug'] : true,
			  'version'       => isset($options['version']) ? $options['version'] : 'v=' . self::version()
			);
			
			JHtml::_('script', $filename, $scriptOptions, $attribs);
		}
		else
		{
			JHtml::_('script', $filename, false, true);
		}
	}
	
	public static function stylesheet($filename, $options = array(), $attribs = array())
	{
		if (version_compare(JVERSION, '3.7.0', 'ge'))
		{
			// StyleSheet loading options
			$stylesheetOptions = array(
			  'relative'      => isset($options['relative']) ? $options['relative'] : true,
			  'pathOnly'      => isset($options['pathOnly']) ? $options['pathOnly'] : false,
			  'detectBrowser' => isset($options['detectBrowser']) ? $options['detectBrowser'] : true,
			  'detectDebug'   => isset($options['detectDebug']) ? $options['detectDebug'] : true,
			  'version'       => isset($options['version']) ? $options['version'] : 'v=' . self::version()
			);
		
			JHtml::_('stylesheet', $filename, $stylesheetOptions, $attribs);
		}
		else
		{
			JHtml::_('stylesheet', $filename, array(), true);
		}
	}
	
	public static function version()
	{
		static $version = null;
		
		if ($version === null)
		{
			$version = 'auto';
			
			$manifest = JPath::clean(JPATH_ADMINISTRATOR . '/components/com_vmreporter/vmreporter.xml');
			
			if (is_file($manifest))
			{
				$xml = simplexml_load_file($manifest);

				if (!empty($xml) && !empty($xml->version))
				{
					$version =  (string) $xml->version;
				}
			}
		}

		return $version;
	}
	
	public static function categories($virtuemart_product_id, $link = true)
	{
		if (!isset(self::$categories[$virtuemart_product_id]))
		{
			$db    = JFactory::getDbo();
			$query = $db->getQuery(true);
			
			$query->select($db->quoteName('c.virtuemart_category_id'))
				->from($db->quoteName('#__virtuemart_product_categories') . ' AS c')
				->join('INNER', $db->quoteName('#__virtuemart_categories') . ' AS cc ON ' . $db->quoteName('cc.virtuemart_category_id') . ' = ' . $db->quoteName('c.virtuemart_category_id') . ' AND ' . $db->quoteName('cc.published') . ' = 1')
				->join('LEFT', $db->quoteName('#__virtuemart_categories_' . VmConfig::$vmlang) . ' AS cl ON ' . $db->quoteName('cl.virtuemart_category_id') . ' = ' . $db->quoteName('c.virtuemart_category_id'));
			
			if (VmConfig::$defaultLang != VmConfig::$vmlang && VmConfig::$langCount > 1)
			{
				$query->select('CASE WHEN ' . $db->quoteName('cl.category_name') . ' IS NULL THEN ' . $db->quoteName('cdl.category_name') . ' ELSE ' . $db->quoteName('cl.category_name') . ' END AS category_name');
				
				$query->join('LEFT', $db->quoteName('#__virtuemart_categories_' . VmConfig::$defaultLang) . ' AS cdl ON ' . $db->quoteName('cdl.virtuemart_category_id') . ' = ' . $db->quoteName('c.virtuemart_category_id'));
			}
			else
			{
				$query->select($db->quoteName('cl.category_name'));
			}
			
			$query->where($db->quoteName('c.virtuemart_product_id') . ' = ' . (int) $virtuemart_product_id);
			
			$db->setQuery($query);
			self::$categories[$virtuemart_product_id] = $db->loadObjectList();
		}
		
		$categories = [];
		
		foreach (self::$categories[$virtuemart_product_id] as $category)
		{
			if (empty($category->category_name))
			{
				$category->category_name = vmText::sprintf('COM_VM_TRANSLATION_MISSING', 'virtuemart_category_id', $category->virtuemart_category_id);
			}
			
			if ($link)
			{
				$categories[] = '<a href="' . JRoute::_('index.php?option=com_virtuemart&view=category&task=edit&cid[]=' . $category->virtuemart_category_id) . '" target="_blank">' . $category->category_name . '</a>';
			}
			else
			{
				$categories[] = $category->category_name;
			}
		}
		
		return implode(', ', $categories);
	}
	
	public static function manufacturers($virtuemart_product_id, $link = true)
	{
		if (!isset(self::$manufacturers[$virtuemart_product_id]))
		{
			$db    = JFactory::getDbo();
			$query = $db->getQuery(true);
			
			$query->select($db->quoteName('m.virtuemart_manufacturer_id'))
				->from($db->quoteName('#__virtuemart_product_manufacturers') . ' AS m')
				->join('INNER', $db->quoteName('#__virtuemart_manufacturers') . ' AS mm ON ' . $db->quoteName('mm.virtuemart_manufacturer_id') . ' = ' . $db->quoteName('m.virtuemart_manufacturer_id') . ' AND ' . $db->quoteName('mm.published') . ' = 1')
				->join('LEFT', $db->quoteName('#__virtuemart_manufacturers_' . VmConfig::$vmlang) . ' AS ml ON ' . $db->quoteName('ml.virtuemart_manufacturer_id') . ' = ' . $db->quoteName('m.virtuemart_manufacturer_id'));
			
			if (VmConfig::$defaultLang != VmConfig::$vmlang && VmConfig::$langCount > 1)
			{
				$query->select('CASE WHEN ' . $db->quoteName('ml.mf_name') . ' IS NULL THEN ' . $db->quoteName('mdl.mf_name') . ' ELSE ' . $db->quoteName('ml.mf_name') . ' END AS mf_name');
				
				$query->join('LEFT', $db->quoteName('#__virtuemart_manufacturers_' . VmConfig::$defaultLang) . ' AS mdl ON ' . $db->quoteName('mdl.virtuemart_manufacturer_id') . ' = ' . $db->quoteName('m.virtuemart_manufacturer_id'));
			}
			else
			{
				$query->select($db->quoteName('ml.mf_name'));
			}
			
			$query->where($db->quoteName('m.virtuemart_product_id') . ' = ' . (int) $virtuemart_product_id);
			
			$db->setQuery($query);
			self::$manufacturers[$virtuemart_product_id] = $db->loadObjectList();
		}
		
		$manufacturers = [];
		
		foreach (self::$manufacturers[$virtuemart_product_id] as $manufacturer)
		{
			if (empty($manufacturer->mf_name))
			{
				$manufacturer->mf_name = vmText::sprintf('COM_VM_TRANSLATION_MISSING', 'virtuemart_manufacturer_id', $manufacturer->virtuemart_manufacturer_id);
			}
			
			if ($link)
			{
				$manufacturers[] = '<a href="' . JRoute::_('index.php?option=com_virtuemart&view=manufacturer&task=edit&cid[]=' . $manufacturer->virtuemart_manufacturer_id) . '" target="_blank">' . $manufacturer->mf_name . '</a>';
			}
			else
			{
				$manufacturers[] = $manufacturer->mf_name;
			}
		}
		
		return implode(', ', $manufacturers);
	}
}
