<?php
/**
 * @package     Reporter for VirtueMart
 * 
 * @copyright   Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Abhishek Das <info@virtueplanet.com> - https://www.virtueplanet.com
 */

defined('_JEXEC') or die;

/**
* VM Reporter Utilities
*/
abstract class VMReporterScript
{
	public static function addOption($name, $value)
	{
		$global  = VMReporterGlobal::getInstance();
		$options = (array) $global->getState('script_options', array());
		
		$name = strtoupper($name);
		$options[$name] = $value;
		
		$global->setState('script_options', $options);
		
		unset($options);
	}
	
	public static function getOptions()
	{
		$global = VMReporterGlobal::getInstance();
		$options = (array) $global->getState('script_options', array());
		
		if (empty($options))
		{
			return;
		}
		
		$doc     = JFactory::getDocument();
		$tab     = $doc->_getTab();
		$lineEnd = $doc->_getLineEnd();
		$options = (!empty($options) && is_array($options)) ? json_encode($options) : null;
		
		$buffer  = $lineEnd;
		$buffer .= $tab . '<script type="text/javascript">' . $lineEnd;
		$buffer .= $tab . $tab . '//<![CDATA[' . $lineEnd;
		$buffer .= $tab . $tab . "(function() {" . $lineEnd;
		
		if (!empty($options))
		{
			$buffer .= $tab . $tab . $tab . 'VMReporter.loadOptions(' . $options . ');' . $lineEnd;
		}
		
		$buffer .= $tab . $tab . "})();"  . $lineEnd;
		$buffer .= $tab . $tab . '//]]>' . $lineEnd;
		$buffer .= $tab . '</script>';
		
		// Reset the list after load.
		$options = array();
		$global->setState('script_options', $options);
		
		return $buffer;
	}
	
	public static function addScript($url, $type = "text/javascript", $defer = false, $async = false)
	{
		$global  = VMReporterGlobal::getInstance();
		$scripts = $global->getState('body_scripts', array());
		
		$scripts[$url]['mime'] = $type;
		$scripts[$url]['defer'] = $defer;
		$scripts[$url]['async'] = $async;
		
		$global->setState('body_scripts', $scripts);
	}
	
	public static function addScriptDeclaration($content, $type = 'text/javascript')
	{
		$global = VMReporterGlobal::getInstance();
		$script = $global->getState('body_script', array());
		$hash   = md5($content);
		
		if (!isset($script[strtolower($type)]))
		{
			$script[strtolower($type)] = array();
		}

		if (!array_key_exists($hash, $script[strtolower($type)]))
		{
			$script[strtolower($type)][$hash] = $content;
		}
		
		$global->setState('body_script', $script);
	}
	
	public static function getAll()
	{
		$global = VMReporterGlobal::getInstance();
		$scripts = $global->getState('body_scripts', array());
		$script = $global->getState('body_script', array());
		$doc = JFactory::getDocument();
		$tab = $doc->_getTab();
		$lnEnd = $doc->_getLineEnd();
		$tagEnd = ' />';
		$buffer = '';

		foreach ($scripts as $strSrc => $strAttr)
		{
			$buffer .= $tab . '<script src="' . $strSrc . '"';
			$defaultMimes = array(
				'text/javascript', 'application/javascript', 'text/x-javascript', 'application/x-javascript'
			);

			if (!is_null($strAttr['mime']) && (!$doc->isHtml5() || !in_array($strAttr['mime'], $defaultMimes)))
			{
				$buffer .= ' type="' . $strAttr['mime'] . '"';
			}

			if ($strAttr['defer'])
			{
				$buffer .= ' defer="defer"';
			}

			if ($strAttr['async'])
			{
				$buffer .= ' async="async"';
			}

			$buffer .= '></script>' . $lnEnd;
		}
		
		foreach ($script as $type => $content)
		{
			$buffer .= $tab . '<script type="' . $type . '">' . $lnEnd;

			// This is for full XHTML support.
			if ($doc->_mime != 'text/html')
			{
				$buffer .= $tab . $tab . '//<![CDATA[' . $lnEnd;
			}
			
			$content = (!empty($content) && is_array($content)) ? implode(chr(13), $content) : '';
			
			$buffer .= $content . $lnEnd;

			// See above note
			if ($doc->_mime != 'text/html')
			{
				$buffer .= $tab . $tab . '//]]>' . $lnEnd;
			}

			$buffer .= $tab . '</script>' . $lnEnd;
		}
		
		return $buffer;
	}
}
