<?php
/**
 * @package     Reporter for VirtueMart
 * 
 * @copyright   Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Abhishek Das <info@virtueplanet.com> - https://www.virtueplanet.com
 */

defined('_JEXEC') or die;

use Joomla\Registry\Registry;

jimport('joomla.form.formfield');

JFormHelper::loadFieldClass('list');

class JFormFieldVMCountries extends JFormFieldList
{
	public $type = 'VMCountries';
	
	protected static $countries = null;
	
	protected function getOptions()
	{
		if (self::$countries === null)
		{
			$db    = JFactory::getDBO();
			$query = $db->getQuery(true)
				->select('c.virtuemart_country_id AS id, c.country_name AS name, c.country_3_code')
				->from('#__virtuemart_countries AS c')
				->where('c.published = 1')
				->order('c.country_name ASC');
				
			try
			{
				$db->setQuery($query);
				self::$countries = $db->loadObjectList();
			}
			catch (Exception $e)
			{
				JFactory::getApplication()->enqueueMessage($e->getMessage(), 'error');
				
				return false;
			}
		}
		
		$lang = JFactory::getLanguage();
		
		$lang->load('com_virtuemart_countries', JPATH_ADMINISTRATOR);
		$lang->load('com_virtuemart_countries', JPATH_ADMINISTRATOR . '/components/com_virtuemart');
		
		$options = array();
		
		foreach (self::$countries as $country)
		{
			$key = 'COM_VIRTUEMART_COUNTRY_' . strtoupper($country->country_3_code);
			$text = $lang->hasKey($key) ? JText::_($key) : $country->name;
			
			$options[] = JHtml::_('select.option', (int) $country->id, $text);
		}
		
		if (version_compare(JVERSION, '4.0.0', 'ge') && $this->multiple)
		{
			$this->layout = 'joomla.form.field.list-fancy-select';
		}
		
		return array_merge(parent::getOptions(), $options);
	}
}
