<?php
/**
 * @package     Reporter for VirtueMart
 * 
 * @copyright   Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Abhishek Das <info@virtueplanet.com> - https://www.virtueplanet.com
 */

defined('_JEXEC') or die;

use Joomla\Registry\Registry;

jimport('joomla.form.formfield');

JFormHelper::loadFieldClass('list');

class JFormFieldVmmanufacturers extends JFormFieldList
{
	public $type = 'vmmanufacturers';
	
	protected function getOptions()
	{
		$options = array();
		
		JLoader::register('VmConfig',        JPATH_ADMINISTRATOR . '/components/com_virtuemart/helpers/config.php');
		JLoader::register('ShopFunctions',   JPATH_ADMINISTRATOR . '/components/com_virtuemart/helpers/shopfunctions.php');
		JLoader::register('TableCategories', JPATH_ADMINISTRATOR . '/components/com_virtuemart/tables/categories.php');
		JLoader::register('VmModel',         JPATH_ADMINISTRATOR . '/components/com_virtuemart/helpers/vmmodel.php');
		
		VmConfig::loadConfig();
		
		$model = VmModel::getModel('Manufacturer');
		$cache = JFactory::getCache('vmreporter_manufacturer_options', '');
		$key   = 'vm_manufacturer_list.options';
		
		$cache->setCaching(1);
		
		$manufacturers = $cache->get($key);
		
		if (empty($manufacturers))
		{
			$manufacturers = $model->getManufacturers(true, true, false);
			
			$cache->store($manufacturers, $key);
		}
		
		if (!empty($manufacturers) && is_array($manufacturers))
		{
			foreach ($manufacturers as $manufacturer)
			{
				$options[] = JHTML::_('select.option', (int) $manufacturer->virtuemart_manufacturer_id, htmlspecialchars($manufacturer->mf_name, ENT_COMPAT, 'UTF-8', false));
			}
		}
		
		if (version_compare(JVERSION, '4.0.0', 'ge') && $this->multiple)
		{
			$this->layout = 'joomla.form.field.list-fancy-select';
		}
		
		return array_merge(parent::getOptions(), $options);
	}
}
