<?php
/**
 * @package     Reporter for VirtueMart
 * 
 * @copyright   Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Abhishek Das <info@virtueplanet.com> - https://www.virtueplanet.com
 */

defined('_JEXEC') or die;

use Joomla\Registry\Registry;

jimport('joomla.form.formfield');

JFormHelper::loadFieldClass('list');

class JFormFieldVmproductcategories extends JFormFieldList
{
	public $type = 'vmproductcategories';
	
	protected static $categoryOptions = array();
	
	protected function getOptions()
	{
		if (!empty($this->value) && is_string($this->value) && strpos($this->value, ',') !== false)
		{
			$parts = explode(',', $this->value);
			
			$this->value = array_map('trim', $parts);
		}
		
		if (version_compare(JVERSION, '4.0.0', 'ge') && $this->multiple)
		{
			$this->layout = 'joomla.form.field.list-fancy-select';
		}
		
		$options = $this->getCategoryListTree();
		
		return array_merge(parent::getOptions(), $options);
	}
	
	protected function getCategoryListTree($parentId = 0, $level = 0, $vendorId = 1, $disabled = array())
	{
		JLoader::register('VmConfig',        JPATH_ADMINISTRATOR . '/components/com_virtuemart/helpers/config.php');
		JLoader::register('ShopFunctions',   JPATH_ADMINISTRATOR . '/components/com_virtuemart/helpers/shopfunctions.php');
		JLoader::register('TableCategories', JPATH_ADMINISTRATOR . '/components/com_virtuemart/tables/categories.php');
		JLoader::register('VmModel',         JPATH_ADMINISTRATOR . '/components/com_virtuemart/helpers/vmmodel.php');
		
		VmConfig::loadConfig();
		VmConfig::loadJLang('com_virtuemart');
		
		$key   = 'vm_category_list.options.parent_id' . $parentId . '.level:' . $level . '.vendor_id:' . $vendorId . 'disabled:' . json_encode($disabled);
		$cache = JFactory::getCache('vmreporter_category_options', '');
		
		$cache->setCaching(1);
		
		$options = $cache->get($key);
		
		if (empty($options))
		{
			$options = $this->getCategoryListOptions($parentId, $level, $vendorId, $disabled);
			
			$cache->store($options, $key);
		}
		
		return (array) $options;
	}

	protected function getCategoryListOptions($parentId = 0, $level = 0, $vendorId = 1, $disabled = array())
	{
		$level++;
		
		$categoryModel = VmModel::getModel('category');
		
		$categoryModel->_noLimit = true;
		
		$categories = $categoryModel->getCategories(true, $parentId, false, '', $vendorId);
		
		if (!empty($categories))
		{
			foreach ($categories as $category)
			{
				$isDisabled              = in_array($category->virtuemart_category_id, $disabled);
				$category_id             = $category->virtuemart_category_id;
				$category_name           = str_repeat (' - ', ($level - 1)) . $category->category_name;
				self::$categoryOptions[] = JHtml::_('select.option', $category_id, $category_name, 'value', 'text', $isDisabled);
				
				if ($categoryModel->hasChildren($category_id))
				{
					$this->getCategoryListOptions($category_id, $level, $vendorId, $disabled);
				}
			}
		}
		
		return self::$categoryOptions;
	}
}
