<?php
/**
 * @package     Reporter for VirtueMart
 * 
 * @copyright   Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Abhishek Das <info@virtueplanet.com> - https://www.virtueplanet.com
 */

defined('_JEXEC') or die;

use Joomla\Registry\Registry;

jimport('joomla.form.formfield');

JFormHelper::loadFieldClass('list');

JLoader::register('VmConfig',        JPATH_ADMINISTRATOR . '/components/com_virtuemart/helpers/config.php');
JLoader::register('ShopFunctions',   JPATH_ADMINISTRATOR . '/components/com_virtuemart/helpers/shopfunctions.php');
JLoader::register('TableCategories', JPATH_ADMINISTRATOR . '/components/com_virtuemart/tables/categories.php');
JLoader::register('VmModel',         JPATH_ADMINISTRATOR . '/components/com_virtuemart/helpers/vmmodel.php');

class JFormFieldVmproducts extends JFormFieldList
{
	public $type = 'vmproducts';
	
	protected static $products = null;
	
	protected function getInput()
	{
		$id    = isset($this->element['id']) ? $this->element['id'] : null;
		$cssId = '#' . $this->getId($id, $this->element['name']);
		
		if (version_compare(JVERSION, '4.0.0', 'ge'))
		{
			$data   = $this->getLayoutData();
			
			$class         = !empty($data['class']) ? $data['class'] : '';
			$hint          = !empty($data['hint']) ? $data['hint'] : '';
			$allowCustom   = !empty($data['allowcustom']) ? $data['allowcustom'] : false;
			$required      = !empty($data['required']) ? $data['required'] : false;
			$minTermLength = !empty($data['mintermlength']) ? $data['mintermlength'] : 2;
			$dataAttribute = !empty($data['data']) ? $data['data'] : '';
			
			$attr  = '';
			$attr .= !empty($data['class']) ? ' class="' . $data['class'] . '"' : '';
			$attr .= ' placeholder="' . htmlspecialchars($hint ?: JText::_('COM_VMREPORTER_HELP_AJAX_PRODUCT_SELECT'), ENT_COMPAT, 'UTF-8', false) . '" ';
			$attr .= $dataAttribute;

			if ($allowCustom)
			{
				$attr .= $allowCustom ? ' allow-custom' : '';
				$attr .= $allowCustom ? ' new-item-prefix="#new#"' : '';
			}

			$attr .= ' remote-search';
			$attr .= ' url="' . JUri::base() . 'index.php?option=com_vmreporter&format=json&task=report.getProducts"';
			$attr .= ' term-key="like"';
			$attr .= ' min-term-length="' . $minTermLength . '"';

			if ($required)
			{
				$attr .= ' required';
			}
			
			JText::script('JGLOBAL_SELECT_PRESS_TO_SELECT');

			JFactory::getDocument()->getWebAssetManager()
				->usePreset('choicesjs')
				->useScript('webcomponent.field-fancy-select');
			
			$html = parent::getInput();
			$html = '<joomla-field-fancy-select ' . $attr . '>' . $html . '</joomla-field-fancy-select>';
			
			return $html;
		}
		else
		{
			$chosenAjaxSettings = new Registry(
				array(
					'selector'      => $cssId,
					'type'          => 'GET',
					'url'           => JUri::base() . 'index.php?option=com_vmreporter&format=json&task=report.getProducts',
					'dataType'      => 'json',
					'jsonTermKey'   => 'like',
					'minTermLength' => 2
				)
			);

			JHtml::_('formbehavior.ajaxchosen', $chosenAjaxSettings);
			
			if (is_string($this->value) && !empty($this->value))
			{
				$this->value = explode(',', $this->value);
			}
			
			$html  = parent::getInput();
			$html .= '<div class="small text-small muted text-muted">' . JText::_('COM_VMREPORTER_HELP_AJAX_PRODUCT_SELECT') . '</div>';
			
			return $html;
		}
	}
	
	protected function getOptions()
	{
		$options = array();
		
		if (!empty($this->value))
		{
			VmConfig::loadConfig();
			VmConfig::loadJLang('com_virtuemart', true);
			
			$model = VmModel::getModel('Product');
			$product_ids = array_map('intval', $this->value);
			$products = $model->getProducts($product_ids);
			
			if (!empty($products))
			{
				foreach ($products as $product)
				{
					$value = (int) $product->virtuemart_product_id;
					$text  = htmlspecialchars($product->product_name, ENT_COMPAT, 'UTF-8', false);
					
					$options[] = JHTML::_('select.option', $value, $text);
				}
			}
		}
		
		return array_merge(parent::getOptions(), $options);
	}
}
