<?php
/**
 * @package     Reporter for VirtueMart
 * 
 * @copyright   Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Abhishek Das <info@virtueplanet.com> - https://www.virtueplanet.com
 */

defined('_JEXEC') or die;

use Joomla\Registry\Registry;

JFormHelper::loadFieldClass('list');

class JFormFieldVmstatuses extends JFormFieldList
{
	public $type = 'vmstatuses';
	
	protected static $statuses = null;
	
	protected function getOptions()
	{
		$options = array();
		
		if(self::$statuses === null)
		{
			$db    = JFactory::getDBO();
			$query = $db->getQuery(true);

			$query->select($db->quoteName('os.order_status_code') . ' AS value')
				->select($db->quoteName('os.order_status_name') . ' AS text')
				->from($db->quoteName('#__virtuemart_orderstates') . ' AS os')
				->where($db->quoteName('os.published') . ' = 1')
				->order($db->quoteName('os.virtuemart_orderstate_id') . ' ASC');
			
			try
			{
				$db->setQuery($query);
				self::$statuses = $db->loadObjectList();
			}
			catch (Exception $e)
			{
				JFactory::getApplication()->enqueueMessage($e->getMessage(), 'error');
				
				return false;
			}
		}
		
		foreach(self::$statuses as $status)
		{
			$options[] = JHtml::_('select.option', $status->value, JText::_($status->text));
		}
		
		if (version_compare(JVERSION, '4.0.0', 'ge') && $this->multiple)
		{
			$this->layout = 'joomla.form.field.list-fancy-select';
		}
		
		return array_merge(parent::getOptions(), $options);
	}
}
