<?php
/**
 * @package     Reporter for VirtueMart
 * 
 * @copyright   Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Abhishek Das <info@virtueplanet.com> - https://www.virtueplanet.com
 */

defined('_JEXEC') or die;

jimport('joomla.filesystem.file');

use Joomla\Registry\Registry;
use Joomla\Utilities\ArrayHelper;

class VMReporterModelReport extends JModelLegacy
{
	/**
	 * Internal memory based cache array of data.
	 *
	 * @var    array
	 */
	protected $cache = array();

	/**
	 * Context string for the model type.  This is used to handle uniqueness
	 * when dealing with the getStoreId() method and caching data structures.
	 *
	 * @var    string
	 */
	protected $context = null;
	
	protected $no_file_access;
	
	protected $product_model;
	
	protected $customfield_model;
	
	protected $payment_model;
	
	protected $shipment_model;
	
	protected $mail_data;
	
	protected $report = array();
	
	public function __construct($config = array())
	{
		parent::__construct($config);
		
		// Guess the context as Option.ModelName.
		if (empty($this->context))
		{
			$this->context = strtolower($this->option . '.' . $this->getName());
		}
		
		$this->product_model       = VmModel::getModel('product');
		$this->customfield_model   = VmModel::getModel('customfields');
		$this->payment_model       = VmModel::getModel('paymentmethod');
		$this->shipment_model      = VmModel::getModel('shipmentmethod');
		
		$this->no_file_access      = '<?php die("Access Denied"); ?>';
		
		$this->desired_order       = array(
			'created_on', 'virtuemart_order_item_id', 'virtuemart_order_id', 'virtuemart_vendor_id', 'order_number',
			'customer_number', 'order_pass', 'order_create_invoice_pass', 'order_currency_id',
			'order_currency', 'user_currency_id', 'user_currency', 'user_currency_rate', 'order_total',
			'order_salesPrice', 'order_billTaxAmount', 'order_billDiscountAmount', 'order_discountAmount',
			'order_subtotal', 'order_tax', 'order_shipment', 'order_shipment_tax', 'order_payment',
			'order_payment_tax', 'coupon_discount', 'coupon_code', 'order_discount',
			'delivery_date', 'order_language', 'ip_address', 'created_by',
			'modified_on', 'modified_by', 'order_status', 'virtuemart_user_id', 'username', 'address_type_name',
			'company', 'title', 'first_name', 'middle_name', 'last_name', 'phone_1', 'phone_2',
			'fax', 'address_1', 'address_2', 'city', 'virtuemart_state_id', 'virtuemart_country_id',
			'zip', 'email', 'agreed', 'tos', 'customer_note', 'country_3_code', 'state_name', 'BTasST',
			'shipto_address_type_name', 'shipto_company', 'shipto_first_name', 'shipto_middle_name',
			'shipto_last_name', 'shipto_address_1', 'shipto_address_2', 'shipto_city', 'shipto_virtuemart_state_id',
			'shipto_virtuemart_country_id', 'shipto_zip', 'shipto_country_3_code', 'shipto_state_name',
			'virtuemart_product_id', 'order_item_sku', 'order_item_name',
			'product_attribute', 'category_id', 'category_name', 'manufacturer_id', 'manufacturer_name',
			'product_quantity', 'product_item_price', 'product_priceWithoutTax', 'product_tax',
			'product_basePriceWithTax', 'product_discountedPriceWithoutTax', 'product_final_price',
			'product_subtotal_discount', 'product_subtotal_with_tax', 'order_item_currency',
			'item_order_status', 'virtuemart_paymentmethod_id', 'payment_name',
			'virtuemart_shipmentmethod_id', 'shipment_name'
		);
	}

	/**
	* Method to auto-populate the model state.
	*
	* Note. Calling getState in this method will result in recursion.
	*/
	protected function populateState($ordering = null, $direction = null) 
	{
		// Initialise variables.
		$app    = JFactory::getApplication();
		$params = JComponentHelper::getParams('com_vmreporter');
		
		// Load the primary key.
		$id = $app->input->getInt('id', 0);
		$this->setState('report.id', $id);

		// Load filter columns.
		$analysis_type  = $app->input->getCmd('analysis_type', 'overview');
		$this->setState('analysis.type', $analysis_type);
		
		// Load the filter state.
		$search      = $app->getUserStateFromRequest($this->context . '.filter.search', 'filter_search');
		$this->setState('filter.search', $search);

		// Load the parameters.
		$this->setState('params', $params);

		// List state information.
		parent::populateState('virtuemart_order_item_id', 'asc');
	}

	/**
	 * Method to get a store id based on the model configuration state.
	 *
	 * This is necessary because the model is used by the component and
	 * different modules that might need different sets of data or different
	 * ordering requirements.
	 *
	 * @param   string  $id  An identifier string to generate the store id.
	 *
	 * @return  string  A store id.
	 */
	protected function getStoreId($id = '')
	{
		return md5($this->context . ':' . $id);
	}

	/**
	 * Returns a Table object, always creating it
	 *
	 * @param   type    $type    The table type to instantiate
	 * @param   string  $prefix  A prefix for the table class name. Optional.
	 * @param   array   $config  Configuration array for model. Optional.
	 *
	 * @return  JTable  A database object
	 */
	public function getTable($type = 'Report', $prefix = 'VMReporterTable', $config = array())
	{
		return JTable::getInstance($type, $prefix, $config);
	}


	public function getReport($pkey = null)
	{
		$pkey = $pkey ? $pkey : $this->state->get('report.id', 0);

		if (!$pkey)
		{
			$this->setError(JText::_('COM_VMREPORTER_ERROR_NOT_FOUND'));
			return false;
		}
		
		if (isset($this->report[$pkey]))
		{
			return $this->report[$pkey];
		}
		
		$report = $this->getTable();
		$report->load($pkey);
		
		$params    = $this->state->get('params');
		$data_dir  = JPATH_SITE . '/media/vmreporter/data';
		$data_dir  = $params->get('data_dir', $data_dir);
		
		if ($report->id)
		{
			$report->valid = true;

			if (!empty($report->file_id))
			{
				$data_file    = JPath::clean($data_dir . '/' . $report->file_id . '.php');
				$report->data = file_get_contents($data_file);
				
				if ($report->data === false)
				{
					$this->setError(JText::_('COM_VMREPORTER_ERROR_REPORT_FILE_NOT_FOUND'));
					return false;
				}
				
				$report->data = str_replace($this->no_file_access, '', $report->data);
				$report->data = @trim($report->data);
			}
		}
		elseif (!$report->data)
		{
			$this->setError(JText::_('COM_VMREPORTER_ERROR_REPORT_DATA_NOT_FOUND'));
			return false;
		}

		$report->data = @json_decode($report->data, true);
		
		if (empty($report->data))
		{
			$this->setError(JText::_('COM_VMREPORTER_ERROR_REPORT_DATA_INVALID'));
			return false;
		}
		
		$this->setState('report.start_date', $report->start_date);
		$this->setState('report.end_date', $report->end_date);
		
		$this->report[$pkey] = $report;
		
		return $this->report[$pkey];
	}
	
	/**
	* Method to mark a report read by the seeing user
	* 
	* @return boolean
	*/
	public function markRead()
	{
		$user_id = (int) JFactory::getUser()->get('id');
		$report  = $this->getReport();
		$result  = true;
		
		if ($report && $report->id > 0 && $user_id)
		{
			$registry   = new Registry($report->users_read);
			$users_read = $registry->toArray();
			
			ArrayHelper::toInteger($users_read);
			
			if (!in_array($user_id, $users_read))
			{
				$users_read[] = $user_id;
				
				$registry   = new Registry($users_read);
				$users_read = $registry->toString();
				
				$db    = $this->getDbo();
				$query = $db->getQuery(true);
				
				$query->update($db->quoteName('#__vmreporter_reports'))
					->set($db->quoteName('users_read') . ' = ' . $db->quote($users_read))
					->where($db->quoteName('id') . ' = ' . $db->quote($report->id));
				
				$db->setQuery($query);
				
				try
				{
					$result = $db->execute();
				}
				catch (RuntimeException $e)
				{
					$this->setError($e->getMessage());
					return false;
				}
			}
		}
		
		return $result;
	}

	/**
	 * Method to get an array of data items.
	 *
	 * @return  mixed  An array of data items on success, false on failure.
	 */
	public function getItems() 
	{
		// Get a storage key.
		$store = $this->getStoreId();
		
		// Try to load the data from internal storage.
		if (isset($this->cache[$store]))
		{
			return $this->cache[$store];
		}
		
		$report = $this->getReport();

		if ($report === false)
		{
			$this->setError($this->getError());
			return false;
		}
		
		$items = $report->data;
		
		$params = JComponentHelper::getParams('com_vmreporter');
		
		foreach ($items as &$item)
		{
			$item = VMReporterHelper::roundPrices($item, $params->get('round_prices', 0));
			
			if (isset($item['quantity']))
			{
				$item['quantity'] = (float) $item['quantity'];
			}
			
			if ($params->get('date_format', 0))
			{
				$format = 'Y-m-d';
				
				if (isset($item['created_on']))
				{
					$created_on = JFactory::getDate($item['created_on']);
					$item['created_on'] = $created_on->format($format);
				}
				
				if (isset($item['modified_on']))
				{
					$modified_on = JFactory::getDate($item['modified_on']);
					$item['modified_on'] = $modified_on->format($format);
				}
			}
		}
		
		$template_id = property_exists($report, 'template_id') ? $report->template_id : 0;
		
		JPluginHelper::importPlugin('vmreporter');
		
		if (version_compare(JVERSION, '4.0.0', 'ge'))
		{
			JFactory::getApplication()->triggerEvent('onPrepareReportItems', array(&$items, $template_id));
		}
		else
		{
			JDispatcher::getInstance()->trigger('onPrepareReportItems', array(&$items, $template_id));
		}
		
		$this->cache[$store] = $items;
		
		return $this->cache[$store];
	}
	
	public function getReportTemplate()
	{
		// Get a storage key.
		$store = $this->getStoreId('template');
		
		// Try to load the data from internal storage.
		if (isset($this->cache[$store]))
		{
			return $this->cache[$store];
		}
		
		$report = $this->getReport();
		
		if ($report === false)
		{
			$this->setError($this->getError());
			return false;
		}
		
		if (empty($report->template_id))
		{
			$this->setError(JText::_('COM_VMREPORTER_ERROR_REPORT_FILE_NOT_FOUND'));
			return false;
		}
		
		$table = $this->getTable('Template');
		
		if (!$table->load($report->template_id))
		{
			$this->setError($table->getError());
			return false;
		}
		
		$registry = new Registry($table->order_fields);
		$table->order_fields = $registry->toArray();
		
		$registry = new Registry($table->order_item_fields);
		$table->order_item_fields = $registry->toArray();
		
		$registry = new Registry($table->bt_fields);
		$table->bt_fields = $registry->toArray();
		
		$registry = new Registry($table->st_fields);
		$table->st_fields = $registry->toArray();
		
		$this->cache[$store] = $table;
		
		return $this->cache[$store];
	}
	
	public function getSortFields($template = null, $items = null)
	{
		$template = ($template === null) ? $this->getReportTemplate() : $template;
		
		if ($template === false)
		{
			return false;
		}
		
		$items = ($items === null) ? $this->getItems() : $items;
		
		if (!isset($items[0]))
		{
			return array();
		}
		
		$fields = array_keys($items[0]);
		
		$order_field       = array_filter($template->order_fields);
		$order_item_fields = array_filter($template->order_item_fields);
		$bt_fields         = array_filter($template->bt_fields);
		$st_fields         = array();
		
		foreach ($template->st_fields as $st_field => $value)
		{
			if (!$value) continue;
			
			$key = 'shipto_' . $st_field;
			
			$st_fields[$key] = $st_field;
		}
		
		$static_fields = array_merge($order_field, $order_item_fields, $bt_fields);
		$sortableFields = array();
		
		foreach ($fields as $field)
		{
			if (array_key_exists($field, $static_fields))
			{
				$label = VMReporterHelper::getFieldLabel($field);
				
				$sortableFields[$field] = JText::_($label);
			}
			elseif (array_key_exists($field, $st_fields))
			{
				$label = VMReporterHelper::getFieldLabel($st_fields[$field]);
				
				$sortableFields[$field] = JText::_('COM_VMREPORTER_SHIPTO_PREFIX') . JText::_($label);
			}
		}
		
		$template_id = property_exists($template, 'id') ? $template->id : 0;
		
		JPluginHelper::importPlugin('vmreporter');
		
		if (version_compare(JVERSION, '4.0.0', 'ge'))
		{
			JFactory::getApplication()->triggerEvent('onPrepareSortableFields', array(&$sortableFields, $template_id));
		}
		else
		{
			JDispatcher::getInstance()->trigger('onPrepareSortableFields', array(&$sortableFields, $template_id));
		}
		
		return $sortableFields;
	}
	
	public function getCSV($template = null, $items = null, $unqiueOrdersOnly = null)
	{
		$sortFields = $this->getSortFields($template, $items);
		
		if (!$sortFields)
		{
			return null;
		}
		
		$items = ($items === null) ? $this->getItems() : $items;
		
		if (empty($items) || !is_array($items))
		{
			return null;
		}

		$template = ($template === null) ? $this->getReportTemplate() : $template;
		
		if (!$template)
		{
			return null;
		}
		
		if (!in_array($unqiueOrdersOnly, array(true, false), true))
		{
			$order_item_fields = array_filter($template->order_item_fields);
			
			if (empty($order_item_fields))
			{
				$unqiueOrdersOnly = true;
			}
		}
		
		$template_id = property_exists($template, 'id') ? $template->id : 0;
		$mailData    = array();

		JPluginHelper::importPlugin('vmreporter');
		
		if (version_compare(JVERSION, '4.0.0', 'ge'))
		{
			JFactory::getApplication()->triggerEvent('onPrepareCsvItems', array(&$items, $sortFields, $template_id, &$mailData));
		}
		else
		{
			JDispatcher::getInstance()->trigger('onPrepareCsvItems', array(&$items, $sortFields, $template_id, &$mailData));
		}
		
		$this->mail_data = $mailData;
		
		ob_start();
		
		$df = fopen('php://output', 'w');
		
		// Set header
		fputcsv($df, array_values($sortFields));
		
		$order_ids = array();
		
		foreach ($items as $row)
		{
			if ($unqiueOrdersOnly && !empty($row['virtuemart_order_id']) && in_array($row['virtuemart_order_id'], $order_ids))
			{
				continue;
			}
			
			if (!empty($row['virtuemart_order_id']))
			{
				$order_ids[] = $row['virtuemart_order_id'];
			}
			
			$row = array_intersect_key($row, $sortFields);
			$row = $this->sortColumns($row, array_keys($sortFields));
			
			fputcsv($df, $row);
		}
		
		fclose($df);
		
		return ob_get_clean();
	}
	
	public function getData()
	{
		$items = $this->getItems();
		
		if (empty($items))
		{
			return array();
		}
		
		$firstItem = current($items);
		$lastItem  = end($items);
		
		reset($items);
		
		$uniqueOrders     = array();
		$uniqueOrderItems = array();
		
		$start_date   = $this->getState('report.start_date');
		$start_date   = ($start_date > 0) ? $start_date : $firstItem['created_on'];
		$end_date     = $this->getState('report.end_date');
		$end_date     = ($end_date > 0) ? $end_date : $lastItem['created_on'];
		$emptyData    = $this->getDataPlaceholder($start_date, $end_date);
		
		$dateFrom     = JFactory::getDate($start_date);
		$dateTo       = JFactory::getDate($end_date);
		$days         = $dateFrom->diff($dateTo)->days;
		$rangeIsMoreThanADay = $days > 0;
		
		$valueData   = $emptyData;
		$countData   = $emptyData;
		$order_total = 0;
		$order_count = 0;
		
		foreach ($items as $item)
		{
			if (in_array($item['virtuemart_order_item_id'], $uniqueOrderItems))
			{
				continue;
			}
			
			$uniqueOrderItems[] = $item['virtuemart_order_item_id'];
			
			$dateStamp = $this->getDateStamp($item['created_on'], $rangeIsMoreThanADay);
			
			if (!in_array($item['virtuemart_order_id'], $uniqueOrders))
			{
				if (isset($valueData[$dateStamp]))
				{
					$valueData[$dateStamp][1] += $item['order_total'];
				}
				
				if (isset($countData[$dateStamp]))
				{
					$countData[$dateStamp][1]++;
				}
				
				$order_total += $item['order_total'];
				$order_count++;
				
				$uniqueOrders[] = $item['virtuemart_order_id'];
			}
		}
		
		$data = new stdClass;
		
		$data->order_total = $order_total;
		$data->order_count = $order_count;
		$data->start_date  = $firstItem['created_on'];
		$data->end_date    = $lastItem['created_on'];
		
		$data->overview = array();
		
		$object        = new stdClass;
		$object->data  = array_values($countData);
		$object->label = JText::_('COM_VMREPORTER_LBL_CHART_ORDER_COUNT');
		
		unset($countData);
		
		$data->overview['counts'] = $object;
		
		$curreny = CurrencyDisplay::getInstance();
		
		$object        = new stdClass;
		$object->data  = array_values($valueData);
		$object->label = JText::sprintf('COM_VMREPORTER_LBL_CHART_ORDER_TOTAL', $curreny->getSymbol());
		
		unset($valueData);
		
		$data->overview['values'] = $object;

		return $data;
	}
	
	public function getAnalysis()
	{
		$items  = $this->getItems();
		$params = $this->getState('params');

		if (empty($items))
		{
			return array();
		}

		$firstItem = current($items);
		$lastItem  = end($items);
		
		reset($items);
		
		$analysis_type = $this->getState('analysis.type');
		
		switch ($analysis_type)
		{
			case 'order_status':
				$name_column = 'order_status_name';
				$order_only  = true;
				break;
				
			case 'virtuemart_paymentmethod_id':
				$name_column = 'payment_name';
				$order_only  = true;
				break;
				
			case 'virtuemart_shipmentmethod_id':
				$name_column = 'shipment_name';
				$order_only  = true;
				break;
				
			case 'customer_number':
				if ($params->get('combine_guest_data', 1))
				{
					$analysis_type = 'virtuemart_user_id';
				}
				$name_column = 'first_name';
				$order_only  = true;
				break;
				
			case 'category_id':
				$name_column = 'category_name';
				$order_only  = false;
				break;
				
			default:
			case 'virtuemart_product_id':
				$analysis_type = 'virtuemart_product_id';
				$name_column   = 'order_item_name';
				$order_only    = false;
				break;
		}
		
		$uniqueOrders     = array();
		$uniqueOrderItems = array();
		$uniqueTypes      = array();
		$itemValues       = array();
		$itemCounts       = array();
		$itemOrderCounts  = array();
		$itemRevenues     = array();
		$start_date       = $this->getState('report.start_date');
		$start_date       = ($start_date > 0) ? $start_date : $firstItem['created_on'];
		$end_date         = $this->getState('report.end_date');
		$end_date         = ($end_date > 0) ? $end_date : $lastItem['created_on'];
		$emptyData        = $this->getDataPlaceholder($start_date, $end_date);
		
		$dateFrom         = JFactory::getDate($start_date);
		$dateTo           = JFactory::getDate($end_date);
		$days             = $dateFrom->diff($dateTo)->days;
		$rangeIsMoreThanADay = $days > 0;
		
		foreach ($items as $item)
		{
			if (!isset($item[$analysis_type]))
			{
				continue;
			}
			
			if (in_array($item['virtuemart_order_item_id'], $uniqueOrderItems))
			{
				continue;
			}
			
			$uniqueOrderItems[] = $item['virtuemart_order_item_id'];
			$dateStamp          = $this->getDateStamp($item['created_on'], $rangeIsMoreThanADay);
			$type_column        = $item[$analysis_type];
			$type_label         = isset($item[$name_column]) ? $item[$name_column] : '';
			$item_url           = null;
			
			if ($analysis_type == 'virtuemart_product_id')
			{
				if (!empty($item['product_attribute']))
				{
					$type_column .= '-' . md5($item['product_attribute']);
					$type_label .= ' - ' . $item['product_attribute'];
				}
				
				if (!empty($item['order_item_sku']))
				{
					$type_label .= ' [' . $item['order_item_sku'] . ']';
				}
				
				$item_url = JRoute::_('index.php?option=com_virtuemart&view=product&task=edit&virtuemart_product_id=' . $item['virtuemart_product_id'], false);
			}
			elseif ($analysis_type == 'category_id')
			{
				$item_url = JRoute::_('index.php?option=com_virtuemart&view=category&task=edit&cid=' . $item['category_id'], false);
			}
			elseif ($analysis_type == 'customer_number' || $analysis_type == 'virtuemart_user_id')
			{
				if ($params->get('combine_guest_data', 1) && empty($item['virtuemart_user_id']))
				{
					$type_label = JText::_('COM_VMREPORTER_GUEST_USERS');
				}
				elseif (empty($type_label))
				{
					$type_label = $item['email'];
				}
				else
				{
					if (!empty($item['middle_name']))
					{
						$type_label .= ' ' . $item['middle_name'];
					}
					
					if (!empty($item['last_name']))
					{
						$type_label .= ' ' . $item['last_name'];
					}
					
					// If guest
					if (empty($item['virtuemart_user_id']))
					{
						if (!empty($item['email']))
						{
							$type_label .= ' [' . $item['email'] . ']';
						}
						
						$type_label .= ' (' . $item['customer_number'] . ')';
					}
				}
				
				if (!empty($item['virtuemart_user_id']))
				{
					$item_url = JRoute::_('index.php?option=com_virtuemart&view=user&task=edit&virtuemart_user_id[]=' . $item['virtuemart_user_id'], false);
				}
			}
			
			if ($order_only)
			{
				if (!in_array($item['virtuemart_order_id'], $uniqueOrders))
				{
					if (!isset($itemValues[$type_column]))
					{
						$itemValues[$type_column] = new stdClass;
						$itemValues[$type_column]->label = $type_label;
						$itemValues[$type_column]->data = $emptyData;
						$itemValues[$type_column]->lines = array('show' => true);
						$itemValues[$type_column]->url = $item_url;
						$itemValues[$type_column]->total = 0;
					}
					
					if (!isset($itemCounts[$type_column]))
					{
						$itemCounts[$type_column] = new stdClass;
						$itemCounts[$type_column]->label = $type_label;
						$itemCounts[$type_column]->data = $emptyData;
						$itemCounts[$type_column]->lines = array('show' => true);
						$itemCounts[$type_column]->url = $item_url;
						$itemCounts[$type_column]->total = 0;
					}
					
					if (!isset($itemOrderCounts[$type_column]))
					{
						$itemOrderCounts[$type_column] = new stdClass;
						$itemOrderCounts[$type_column]->label = $type_label;
						$itemOrderCounts[$type_column]->data = $emptyData;
						$itemOrderCounts[$type_column]->lines = array('show' => true);
						$itemOrderCounts[$type_column]->url = $item_url;
						$itemOrderCounts[$type_column]->total = 0;
					}
					
					if (!isset($itemRevenues[$type_column]))
					{
						$itemRevenues[$type_column] = new stdClass;
						$itemRevenues[$type_column]->label = $type_label;
						$itemRevenues[$type_column]->data = 0;
						$itemRevenues[$type_column]->url = $item_url;
					}

					if (isset($itemValues[$type_column]->data[$dateStamp]))
					{
						$itemValues[$type_column]->data[$dateStamp][1] += $item['order_total'];
					}
					
					if (isset($itemCounts[$type_column]->data[$dateStamp]))
					{
						$itemCounts[$type_column]->data[$dateStamp][1]++;
					}
					
					if (isset($itemOrderCounts[$type_column]->data[$dateStamp]))
					{
						$itemOrderCounts[$type_column]->data[$dateStamp][1]++;
					}
					
					$itemValues[$type_column]->total += $item['order_total'];
					$itemCounts[$type_column]->total++;
					$itemOrderCounts[$type_column]->total++;
					$itemRevenues[$type_column]->data += $item['order_total'];

					$uniqueOrders[] = $item['virtuemart_order_id'];
				}
			}
			else
			{
				if (!isset($itemValues[$type_column]))
				{
					$itemValues[$type_column] = new stdClass;
					$itemValues[$type_column]->label = $type_label;
					$itemValues[$type_column]->data = $emptyData;
					$itemValues[$type_column]->lines = array('show' => true);
					$itemValues[$type_column]->url = $item_url;
					$itemValues[$type_column]->total = 0;
				}
				
				if (!isset($itemCounts[$type_column]))
				{
					$itemCounts[$type_column] = new stdClass;
					$itemCounts[$type_column]->label = $type_label;
					$itemCounts[$type_column]->data = $emptyData;
					$itemCounts[$type_column]->lines = array('show' => true);
					$itemCounts[$type_column]->url = $item_url;
					$itemCounts[$type_column]->total = 0;
				}
				
				if (!isset($itemOrderCounts[$type_column]))
				{
					$itemOrderCounts[$type_column] = new stdClass;
					$itemOrderCounts[$type_column]->label = $type_label;
					$itemOrderCounts[$type_column]->data = $emptyData;
					$itemOrderCounts[$type_column]->lines = array('show' => true);
					$itemOrderCounts[$type_column]->url = $item_url;
					$itemOrderCounts[$type_column]->total = 0;
				}
				
				if (!isset($itemRevenues[$type_column]))
				{
					$itemRevenues[$type_column] = new stdClass;
					$itemRevenues[$type_column]->label = $type_label;
					$itemRevenues[$type_column]->data = 0;
					$itemRevenues[$type_column]->url = $item_url;
				}
				
				if (isset($itemValues[$type_column]->data[$dateStamp]))
				{
					$itemValues[$type_column]->data[$dateStamp][1] += $item['product_subtotal_with_tax'];
				}
				
				if (isset($itemCounts[$type_column]->data[$dateStamp]))
				{
					$itemCounts[$type_column]->data[$dateStamp][1] += $item['product_quantity'];
				}
				
				if (isset($itemOrderCounts[$type_column]->data[$dateStamp]))
				{
					$itemOrderCounts[$type_column]->data[$dateStamp][1]++;
				}
				
				$itemValues[$type_column]->total += $item['product_subtotal_with_tax'];
				$itemCounts[$type_column]->total += $item['product_quantity'];
				$itemOrderCounts[$type_column]->total++;
				$itemRevenues[$type_column]->data += $item['product_subtotal_with_tax'];
			}
		}
		
		$result = new stdClass;
		
		foreach ($itemValues as &$item)
		{
			$item->data = array_values($item->data);
		}
		
		foreach ($itemCounts as &$item)
		{
			$item->data = array_values($item->data);
		}
		
		foreach ($itemOrderCounts as &$item)
		{
			$item->data = array_values($item->data);
		}
		
		$result->order_totals = array_values($itemValues);
		
		// Clean some memory
		unset($itemValues);
		
		$result->order_counts = array_values($itemCounts);
		
		unset($itemCounts);
		
		$result->item_order_counts = array_values($itemOrderCounts);
		
		unset($itemOrderCounts);
		
		$result->revenues = array_values($itemRevenues);
		
		unset($itemRevenues);

		return $result;
	}
	

	protected function getDataPlaceholder($strDateFrom, $strDateTo)
	{
		$dateFrom = JFactory::getDate($strDateFrom);
		$dateTo = JFactory::getDate($strDateTo);
		$days = $dateFrom->diff($dateTo)->days;
		$rangeIsMoreThanADay = $days > 0;

		// takes two dates formatted as j M Y and creates an
		// inclusive array of the dates between the from and to dates.
		$data = array();
		
		$iDateFrom = $this->getDateStamp($strDateFrom, $rangeIsMoreThanADay);
		$iDateTo = $this->getDateStamp($strDateTo, $rangeIsMoreThanADay);

		if ($iDateTo > $iDateFrom)
		{
			$data[$iDateFrom] = array($iDateFrom * 1000, 0); // first entry
			
			while ($iDateFrom <= $iDateTo)
			{
				if ($days > 0)
				{
					$iDateFrom += 86400; // add 24 hours
				}
				else
				{
					$iDateFrom += 3600; // add 1 hour
				}
				
				$data[$iDateFrom] = array($iDateFrom * 1000, 0);
			}
		}
		else
		{
			$data[$iDateFrom] = array($iDateFrom * 1000, 0);
		}

		return $data;
	}
	
	protected function getDateStamp($datetimeStr, $resetTimeToMidnight)
	{
		$datetime = JFactory::getDate($datetimeStr);
		
		if ($resetTimeToMidnight)
		{
			$date = JFactory::getDate($datetime->format('Y-m-d') . ' 00:00:00'); 
			$stamp = $date->toUnix();
		}
		else
		{
			$date = JFactory::getDate($datetime->format('Y-m-d H') . ':00:00'); 
			$stamp = $date->toUnix();
		}
		
		unset($datetime);
		unset($date);
		
		return $stamp;
	}

	protected function buildNewReport($template)
	{
		if (empty(VmConfig::$vmlang))
		{
			VmConfig::setdbLanguageTag();
		}

		$db    = $this->getDbo();
		$query = $db->getQuery(true);
		
		// Get order table columns
		$order_table_columns = VMReporterHelper::getColumns('#__virtuemart_orders', array('order_currency', 'user_currency_id', 'order_billTax', 'o_hash', 'virtuemart_paymentmethod_id', 'virtuemart_shipmentmethod_id', 'locked_on', 'locked_by'));
		
		// Get order items table columns
		$order_item_table_columns = VMReporterHelper::getColumns('#__virtuemart_order_items',  array('virtuemart_order_item_id', 'order_status', 'oi_hash', 'created_on', 'created_by', 'modified_on', 'modified_by', 'locked_on', 'locked_by'));
		
		// Get order user info table columns
		$order_userinfo_table_columns = VMReporterHelper::getColumns('#__virtuemart_order_userinfos', array('created_on', 'created_by', 'address_type', 'virtuemart_order_id', 'modified_on', 'modified_by', 'locked_on', 'locked_by'));
		
		if (!$order_table_columns || !$order_item_table_columns || !$order_userinfo_table_columns)
		{
			$this->setError($this->getError());
			return false;
		}
		
		// Basic order details
		$query->select('oi.virtuemart_order_item_id')
			->select($this->addAliasToColumns($order_table_columns, 'o'))
			->from($db->quoteName('#__virtuemart_order_items') . ' AS oi')
			->join('INNER', $db->quoteName('#__virtuemart_orders') . ' AS o ON o.virtuemart_order_id = oi.virtuemart_order_id');
		
		// Add order status name
		$query->select('os.order_status_name')
			->join('LEFT', $db->quoteName('#__virtuemart_orderstates') . ' AS os ON os.order_status_code = o.order_status');

		// Add username
		$query->select('ju.username')
			->join('LEFT', $db->quoteName('#__users') . ' AS ju ON ju.id = o.virtuemart_user_id');

		// Add order items details
		$query->select($this->addAliasToColumns($order_item_table_columns, 'oi'));
	
		// Add user's billing information
		$query->select($this->addAliasToColumns($order_userinfo_table_columns, 'ou'))
			->join('LEFT', $db->quoteName('#__virtuemart_order_userinfos') . ' AS ou ON ou.virtuemart_order_id = o.virtuemart_order_id AND ou.address_type = ' . $db->quote('BT'));
		
		// Add country code if country field exists
		if (in_array('virtuemart_country_id', $order_userinfo_table_columns))
		{
			$query->select('bc.country_name AS country_name, bc.country_3_code AS country_3_code')
				->join('LEFT', $db->quoteName('#__virtuemart_countries') . ' AS bc ON bc.virtuemart_country_id = ou.virtuemart_country_id');

			if (!empty($template->countries) && is_array($template->countries))
			{
				if (version_compare(JVERSION, '4.0.0', 'ge'))
				{
					Joomla\Utilities\ArrayHelper::toInteger($template->countries);
				}
				else
				{
					JArrayHelper::toInteger($template->countries);
				}
				
				if (count($template->countries) == 1)
				{
					$query->where('ou.virtuemart_country_id = ' . (int) $template->countries[0]);
				}
				else
				{
					$query->where('ou.virtuemart_country_id IN (' . implode(',', $template->countries) . ')');
				}
			}
		}
		
		// Add state name if field exists
		if (in_array('virtuemart_state_id', $order_userinfo_table_columns))
		{
			$query->select('bs.state_name AS state_name')
				->join('LEFT', $db->quoteName('#__virtuemart_states') . ' AS bs ON bs.virtuemart_state_id = ou.virtuemart_state_id');
		}

		$ignore_st_userinfo_fields = array('virtuemart_user_id', 'agreed', 'tos', 'customer_note');
		$st_userinfo_fields = array_diff($order_userinfo_table_columns, $ignore_st_userinfo_fields);

		// Add user's shipping information
		$query->select($this->addAliasToColumns($st_userinfo_fields, 'ous', 'shipto_'))
			->join('LEFT', $db->quoteName('#__virtuemart_order_userinfos') . ' AS ous ON ous.virtuemart_order_id = o.virtuemart_order_id AND ous.address_type = ' . $db->quote('ST'));

		// Add country code if country field exists
		if (in_array('virtuemart_country_id', $order_userinfo_table_columns))
		{
			$query->select('sc.country_name AS shipto_country_name, sc.country_3_code AS shipto_country_3_code')
				->join('LEFT', $db->quoteName('#__virtuemart_countries') . ' AS sc ON sc.virtuemart_country_id = ous.virtuemart_country_id');

			if (!empty($template->st_countries) && is_array($template->st_countries))
			{
				if (version_compare(JVERSION, '4.0.0', 'ge'))
				{
					Joomla\Utilities\ArrayHelper::toInteger($template->st_countries);
				}
				else
				{
					JArrayHelper::toInteger($template->st_countries);
				}
				
				if (count($template->st_countries) == 1)
				{
					$query->where('ous.virtuemart_country_id = ' . (int) $template->st_countries[0]);
				}
				else
				{
					$query->where('ous.virtuemart_country_id IN (' . implode(',', $template->st_countries) . ')');
				}
			}
		}
		
		// Add state name if field exists
		if (in_array('virtuemart_state_id', $order_userinfo_table_columns))
		{
			$query->select('ss.state_name AS shipto_state_name')
				->join('LEFT', $db->quoteName('#__virtuemart_states') . ' AS ss ON ss.virtuemart_state_id = ous.virtuemart_state_id');
		}
		
		if (property_exists($template, 'include_child') && $template->include_child)
		{
			$query->join('LEFT', $db->quoteName('#__virtuemart_products') . ' AS pp ON pp.product_parent_id > 0 AND pp.virtuemart_product_id = oi.virtuemart_product_id');
		}

		// Add product category
		$query->select('pc.virtuemart_category_id AS category_id, pcn.category_name');
		
		if (property_exists($template, 'include_child') && $template->include_child)
		{
			$query->join('LEFT', $db->quoteName('#__virtuemart_product_categories') . ' AS pc ON pc.virtuemart_product_id = oi.virtuemart_product_id OR pc.virtuemart_product_id = pp.product_parent_id');
		}
		else
		{
			$query->join('LEFT', $db->quoteName('#__virtuemart_product_categories') . ' AS pc ON pc.virtuemart_product_id = oi.virtuemart_product_id');
		}
		
		$query->join('LEFT', $db->quoteName('#__virtuemart_categories_' . VmConfig::$vmlang) . ' AS pcn ON pcn.virtuemart_category_id = pc.virtuemart_category_id');

		// Add product manufacturer 
		$query->select('pm.virtuemart_manufacturer_id AS manufacturer_id, pmn.mf_name AS manufacturer_name');
		
		if (property_exists($template, 'include_child') && $template->include_child)
		{
			$query->join('LEFT', $db->quoteName('#__virtuemart_product_manufacturers') . ' AS pm ON pm.virtuemart_product_id = oi.virtuemart_product_id OR pm.virtuemart_product_id = pp.product_parent_id');
		}
		else
		{
			$query->join('LEFT', $db->quoteName('#__virtuemart_product_manufacturers') . ' AS pm ON pm.virtuemart_product_id = oi.virtuemart_product_id');
		}
	
		$query->join('LEFT', $db->quoteName('#__virtuemart_manufacturers_' . VmConfig::$vmlang) . ' AS pmn ON pmn.virtuemart_manufacturer_id = pm.virtuemart_manufacturer_id');

		// Add order items status name
		$query->select('ois.order_status_name AS item_order_status_name, oi.order_status AS item_order_status')
			->join('LEFT', $db->quoteName('#__virtuemart_orderstates') . ' AS ois ON ois.order_status_code = oi.order_status');

		// Add payment method name
		$query->select('o.virtuemart_paymentmethod_id, opm.payment_name')
			->join('LEFT', $db->quoteName('#__virtuemart_paymentmethods_' . VmConfig::$vmlang) . ' AS opm ON opm.virtuemart_paymentmethod_id = o.virtuemart_paymentmethod_id');

		// Add shipment method name
		$query->select('o.virtuemart_shipmentmethod_id, osm.shipment_name')
			->join('LEFT', $db->quoteName('#__virtuemart_shipmentmethods_' . VmConfig::$vmlang) . ' AS osm ON osm.virtuemart_shipmentmethod_id = o.virtuemart_shipmentmethod_id');

		// Add order currency name
		$query->select('oc.currency_code_3 AS order_currency')
			->join('LEFT', $db->quoteName('#__virtuemart_currencies') . ' AS oc ON oc.virtuemart_currency_id = o.order_currency');

		// Add user currency name
		$query->select('ouc.currency_code_3 AS user_currency')
			->join('LEFT', $db->quoteName('#__virtuemart_currencies') . ' AS ouc ON ouc.virtuemart_currency_id = o.user_currency_id');

		if (!empty($template->products) && is_array($template->products))
		{
			if (version_compare(JVERSION, '4.0.0', 'ge'))
			{
				Joomla\Utilities\ArrayHelper::toInteger($template->products);
			}
			else
			{
				JArrayHelper::toInteger($template->products);
			}
			
			if (count($template->products) == 1)
			{
				if (property_exists($template, 'include_child') && $template->include_child)
				{
					$query->where('oi.virtuemart_product_id = ' . (int) $template->products[0] . ' OR pp.product_parent_id = ' . (int) $template->products[0]);
				}
				else
				{
					$query->where('oi.virtuemart_product_id = ' . (int) $template->products[0]);
				}
			}
			else
			{
				if (property_exists($template, 'include_child') && $template->include_child)
				{
					$query->where('oi.virtuemart_product_id IN (' . implode(',', $template->products) . ') OR pp.product_parent_id IN (' . implode(',', $template->products) . ')');
				}
				else
				{
					$query->where('oi.virtuemart_product_id IN (' . implode(',', $template->products) . ')');
				}
			}
		}
		
		if (!empty($template->statuses) && is_array($template->statuses))
		{
			$template->statuses = array_values($template->statuses);
			
			if (count($template->statuses) == 1)
			{
				$query->where('o.order_status = ' . $db->quote($template->statuses[0]));
			}
			else
			{
				$query->where('o.order_status IN (' . implode(',', $db->quote($template->statuses)) . ')');
			}
		}
		
		if (!empty($template->categories) && is_array($template->categories))
		{
			if (version_compare(JVERSION, '4.0.0', 'ge'))
			{
				Joomla\Utilities\ArrayHelper::toInteger($template->categories);
			}
			else
			{
				JArrayHelper::toInteger($template->categories);
			}
			
			if (count($template->categories) == 1)
			{
				$query->where('pc.virtuemart_category_id = ' . (int) $template->categories[0]);
			}
			else
			{
				$query->where('pc.virtuemart_category_id IN (' . implode(',', $template->categories) . ')');
			}
		}
		
		if (!empty($template->manufacturers) && is_array($template->manufacturers))
		{
			if (version_compare(JVERSION, '4.0.0', 'ge'))
			{
				Joomla\Utilities\ArrayHelper::toInteger($template->manufacturers);
			}
			else
			{
				JArrayHelper::toInteger($template->manufacturers);
			}
			
			if (count($template->manufacturers) == 1)
			{
				$query->where('pm.virtuemart_manufacturer_id = ' . (int) $template->manufacturers[0]);
			}
			else
			{
				$query->where('pm.virtuemart_manufacturer_id IN (' . implode(',', $template->manufacturers) . ')');
			}
		}

		$usersQuerySet = false;

		if (!empty($template->shopper_groups))
		{
			if (version_compare(JVERSION, '4.0.0', 'ge'))
			{
				Joomla\Utilities\ArrayHelper::toInteger($template->shopper_groups);
			}
			else
			{
				JArrayHelper::toInteger($template->shopper_groups);
			}

			$defaultGuestGroup = VMReporterHelper::getDefaultShopperGroup(true);
			$defaultGroup      = VMReporterHelper::getDefaultShopperGroup(false);
			$includeGuests     = !empty($defaultGuestGroup) && in_array($defaultGuestGroup->virtuemart_shoppergroup_id, $template->shopper_groups);
			$includeDefault    = !empty($defaultGroup) && in_array($defaultGroup->virtuemart_shoppergroup_id, $template->shopper_groups);

			if ($includeDefault && $includeGuests)
			{
				$query->where('ou.virtuemart_user_id >= 0');

				$usersQuerySet = true;
			}
			elseif ($includeDefault)
			{
				$query->where('ou.virtuemart_user_id > 0');

				$usersQuerySet = true;
			}
			elseif ($includeGuests)
			{
				$query->where('ou.virtuemart_user_id = 0');

				$usersQuerySet = true;
			}
			else
			{
				$users_by_groups = VMReporterHelper::getUsersByShopperGroups($template->shopper_groups);

				if (empty($users_by_groups))
				{
					// No users found. Return empty report.
					return array();
				}

				if (version_compare(JVERSION, '4.0.0', 'ge'))
				{
					Joomla\Utilities\ArrayHelper::toInteger($template->users);
				}
				else
				{
					JArrayHelper::toInteger($template->users);
				}

				$template->users = array_merge($template->users, $users_by_groups);
				$template->users = array_unique($template->users); 
			}
		}
		
		if (!$usersQuerySet)
		{
		if (!empty($template->guests_only))
		{
			$query->where('ou.virtuemart_user_id = 0');
		}
		elseif (!empty($template->users) && is_array($template->users))
		{
			if (version_compare(JVERSION, '4.0.0', 'ge'))
			{
				Joomla\Utilities\ArrayHelper::toInteger($template->users);
			}
			else
			{
				JArrayHelper::toInteger($template->users);
			}
			
			if (count($template->users) == 1)
			{
				$query->where('ou.virtuemart_user_id = ' . (int) $template->users[0]);
			}
			else
			{
				$query->where('ou.virtuemart_user_id IN (' . implode(',', $template->users) . ')');
			}
		}
		}

		if (!empty($template->calculation_rules))
		{
			if (version_compare(JVERSION, '4.0.0', 'ge'))
			{
				Joomla\Utilities\ArrayHelper::toInteger($template->calculation_rules);
			}
			else
			{
				JArrayHelper::toInteger($template->calculation_rules);
			}

			$ordersByCalculationRules = VMReporterHelper::getOrderIdsByCalculationRules($template->calculation_rules);

			if (empty($ordersByCalculationRules))
			{
				return array();
			}

			if (count($ordersByCalculationRules) == 1)
			{
				$query->where('oi.virtuemart_order_id = ' . $ordersByCalculationRules[0]);
			}
			else
			{
				$query->where('oi.virtuemart_order_id IN (' . implode(',', $ordersByCalculationRules) . ')');
			}
		}

		if (!empty($template->period))
		{
			$start_date = null;
			$end_date = JFactory::getDate()->toSql();
			
			switch($template->period)
			{
				case 'last_month':
					$start_date = JFactory::getDate('first day of last month midnight')->toSql();
					$end_date_object = JFactory::getDate('first day of this month midnight');
					$end_date_object->modify('-1 second');
					$end_date = $end_date_object->toSql();
					break;
					
				case 'last_year':
					$start_date = JFactory::getDate('first day of january last year midnight')->toSql();
					$end_date_object = JFactory::getDate('first day of january this year midnight');
					$end_date_object->modify('-1 second');
					$end_date = $end_date_object->toSql();
					break;
					
				case 'last_week':
					$date = JFactory::getDate('last week monday');
					$start_date = $date->toSql();
					$date->modify('+1 week')->modify('-1 second');
					$end_date = $date->toSql();
					break;
					
				case 'this_month':
					$start_date = JFactory::getDate('first day of this month midnight')->toSql();
					break;
					
				case 'this_year':
					$start_date = JFactory::getDate('first day of january this year midnight')->toSql();
					break;
					
				case 'this_week':
					$start_date = JFactory::getDate('this week monday')->toSql();
					break;
					
				case 'custom_days':
					$start_date = JFactory::getDate($template->days . ' days ago midnight')->toSql();
					break;
					
				case 'fixed':
					$start_date_input = JFactory::getDate($template->start_date);
					$start_date = JFactory::getDate($start_date_input->format('Y-m-d') . ' 00:00:00')->toSql(); 
					$end_date_input = JFactory::getDate($template->end_date);
					$end_date = JFactory::getDate($end_date_input->format('Y-m-d') . ' 23:59:59')->toSql(); 
					break;
			}
			
			$time_field = 'o.created_on';
			
			if (!empty($template->time_field) && $template->time_field == 'modified_on')
			{
				$time_field = 'o.modified_on';
			}

			if ($start_date > 0)
			{
				$query->where($db->quoteName($time_field) . ' >= ' . $db->quote($start_date));
				
				$this->setState('report.start_date', $start_date);
			}
			
			if ($end_date > 0)
			{
				$query->where($db->quoteName($time_field) . ' <= ' .  $db->quote($end_date));
				
				$this->setState('report.end_date', $end_date);
			}
		}

		// Group by order items
		$query->group($this->addAliasToColumns(array_merge(array('virtuemart_order_item_id'), $order_item_table_columns), 'oi'));

		if (!empty($template->limit) && is_numeric($template->limit))
		{
			// Set Limit
			$db->setQuery($query, 0, $template->limit);
		}
		else
		{
			$db->setQuery($query);
		}
		
		try
		{
			$results = $db->loadObjectList();
		}
		catch(Exception $e)
		{
			$this->setError($e->getMessage());
			return false;
		}
		
		return $results;
	}
	
	public function generate($template_id, $send_mail = false, $email_ids = '')
	{
		if (empty($template_id))
		{
			$this->setError(JText::_('COM_VMREPORTER_ERROR_NO_TEMPLATE_SELECTED'));
			return false;
		}
		
		$templateModel = JModelLegacy::getInstance('Template', 'VMReporterModel', array('ignore_request' => true));
		
		$template = $templateModel->getItem($template_id);
		
		if (empty($template->id))
		{
			$this->setError(JText::_('COM_VMREPORTER_ERROR_NO_TEMPLATE_SELECTED'));
			return false;
		}
		
		$params = JComponentHelper::getParams('com_vmreporter');
		
		// Build the report from VirtueMart database tables
		$items  = $this->buildNewReport($template);
		
		if ($items === false)
		{
			return false;
		}
		
		if (empty($items))
		{
			$this->setError(JText::_('COM_VMREPORTER_MESSAGE_NO_REPORTS_FOUND'));
			return false;
		}
		
		foreach ($items as &$item)
		{
			$this->cleanRow($item);
		}

		// Now prepare data to save
		$data = array();
		
		$data['template_id'] = $template->id;
		
		if ($params->get('data_handler', 'file') == 'file')
		{
			$file_id = md5('template_id:' . $template->id . '.microtime:' . microtime()) . '-' . uniqid('vmreporter-');
			
			if (!$this->saveDataToFile($file_id, $items))
			{
				$this->setError($this->getError());
				return false;
			}
			
			$data['file_id'] = $file_id;
		}
		else
		{
			$data['data'] = $items;
		}
		
		$data['time_field'] = $template->time_field;
		
		$start_date = $this->getState('report.start_date');
		$end_date   = $this->getState('report.end_date');
		
		if ($start_date)
		{
			$data['start_date'] = JFactory::getDate($start_date)->toSql();
		}
		
		if ($end_date)
		{
			$data['end_date'] = JFactory::getDate($end_date)->toSql();
		}
		
		$data['users_read'] = '';
		
		$table = $this->getTable();
		
		try
		{
			// Bind the data.
			if (!$table->bind($data))
			{
				$this->setError($table->getError());
				return false;
			}
			
			// Check the data.
			if (!$table->check())
			{
				$this->setError($table->getError());
				return false;
			}
			
			// Store the data.
			if (!$table->store())
			{
				$this->setError($table->getError());
				return false;
			}
		}
		catch (Exception $e)
		{
			$this->setError($e->getMessage());
			return false;
		}
		
		if ($send_mail)
		{
			$this->sendMails($items, $template, $email_ids, $data);
		}

		return true;
	}
	
	protected function sendMails($items, $template, $email_ids, $data)
	{
		if (!empty($email_ids))
		{
			$email_ids = explode(',', $email_ids);
			$email_ids = array_filter($email_ids);
			
			foreach ($email_ids as $key => &$email_id)
			{
				if (!JMailHelper::isEmailAddress($email_id))
				{
					unset($email_ids[$key]);
				}
			}

			if (empty($email_ids))
			{
				// No valid email address found
				return false;
			}
			
			$app      = JFactory::getApplication();
			$config   = JFactory::getConfig();
			$lang     = JFactory::getLanguage();
			$filter   = JFilterInput::getInstance();
			$mailer   = JFactory::getMailer();
			$params   = JComponentHelper::getParams('com_vmreporter');
			$from     = $config->get('mailfrom');
			$fromName = $config->get('fromname');
			$siteName = $config->get('sitename');
			$siteUrl  = JUri::root();
			$currency = CurrencyDisplay::getInstance();
			
			$mailer->setSubject($template->alias);
			
			if (!$mailer->addRecipient($email_ids))
			{
				return false;
			}
			
			$autoReplyTo = true;
			
			if ($config->get('replyto'))
			{
				$mailer->addReplyTo($config->get('replyto'), $config->get('replytoname'));
				$autoReplyTo = false;
			}
			
			if ($mailer->setSender(array($from, $fromName, $autoReplyTo)) === false)
			{
				return false;
			}
			
			if ($params->get('report_as_attachment', 1))
			{
				$template_id = property_exists($template, 'id') ? $template->id : 0;
				
				JPluginHelper::importPlugin('vmreporter');
				
				if (version_compare(JVERSION, '4.0.0', 'ge'))
				{
					JFactory::getApplication()->triggerEvent('onPrepareReportItems', array(&$items, $template_id));
				}
				else
				{
					JDispatcher::getInstance()->trigger('onPrepareReportItems', array(&$items, $template_id));
				}
				
				$attachment = $this->getCSV($template, $items);
				$filename   = (!empty($template->download_filename) ? $template->download_filename : $params->get('download_filename', 'report')) . '.csv';
				$filename   = JFile::makeSafe($filename);
				
				$mailer->addStringAttachment($attachment, $filename);
			}
			
			if ($params->get('email_format', 'html') == 'html')
			{
				$displayData = array(
					'template' => $template, 'items' => $items, 'emails' => $email_ids,
					'siteName' => $siteName, 'siteUrl' => $siteUrl, 'params' => $params,
					'data' => $data, 'mailData' => $this->mail_data, 'currency' => $currency
				);
				
				$body = VMReporterHelper::renderLayout('mail', $displayData);
				
				$mailer->isHtml(true);
			}
			else
			{
				if ($params->get('report_as_attachment', 1))
				{
					$body = JText::sprintf('COM_VMREPORTER_MAIL_BODY_WITH_ATTACHMENT', $siteName, $siteName, $siteUrl);
				}
				else
				{
					$body = JText::sprintf('COM_VMREPORTER_MAIL_BODY_WITHOUT_ATTACHMENT', $siteName, $siteName, $siteUrl);
				}
				
				$mailer->isHtml(false);
			}
			
			$mailer->setBody($body);
			
			$result = $mailer->Send();
			
			if (!$result && $mailer->ErrorInfo)
			{
				$this->setError(JText::_($mailer->ErrorInfo));
			}
			
			return $result;
		}
	}
	
	/**
	 * Method to test whether a record can be deleted.
	 *
	 * @param   object  $record  A record object.
	 *
	 * @return  boolean  True if allowed to delete the record. Defaults to the permission for the component.
	 */
	protected function canDelete($record)
	{
		return JFactory::getUser()->authorise('core.delete', 'com_vmreporter');
	}
	
	/**
	 * Method to delete one or more records.
	 *
	 * @param   array  &$pks  An array of record primary keys.
	 *
	 * @return  boolean  True if successful, false if an error occurs.
	 */
	public function delete(&$pks)
	{
		$app      = JFactory::getApplication();
		$pks      = (array) $pks;
		$table    = $this->getTable();
		$params   = JComponentHelper::getParams('com_vmreporter');
		$data_dir = JPATH_SITE . '/media/vmreporter/data';
		$data_dir = $params->get('data_dir', $data_dir);

		// Iterate the items to delete each one.
		foreach ($pks as $i => $pk)
		{
			if ($table->load($pk))
			{
				if ($this->canDelete($table))
				{
					if (!empty($table->file_id))
					{
						$data_file = JPath::clean($data_dir . '/' . $table->file_id . '.php');
					}
					
					if (!$table->delete($pk))
					{
						$this->setError($table->getError());
						return false;
					}
					
					if (is_file($data_file))
					{
						if (!JFile::delete($data_file))
						{
							$app->enqueueMessage(JText::sprintf('COM_VMREPORTER_ERROR_DELETE_DATA_FILE', $data_dir), 'warning');
						}
					}
				}
				else
				{
					// Prune items that you can't change.
					unset($pks[$i]);
					$error = $this->getError();

					if ($error)
					{
						JLog::add($error, JLog::WARNING, 'jerror');
						return false;
					}
					else
					{
						JLog::add(JText::_('JLIB_APPLICATION_ERROR_DELETE_NOT_PERMITTED'), JLog::WARNING, 'jerror');
						return false;
					}
				}
			}
			else
			{
				$this->setError($table->getError());
				return false;
			}
		}

		return true;
	}
	
	
	protected function saveDataToFile($file_id, $items)
	{
		$params    = JComponentHelper::getParams('com_vmreporter');
		$data_dir  = JPATH_SITE . '/media/vmreporter/data';
		$data_dir  = $params->get('data_dir', $data_dir);
		$data_file = JPath::clean($data_dir . '/' . $file_id . '.php');
		
		$buffer  = $this->no_file_access;
		$buffer .= json_encode($items, JSON_UNESCAPED_UNICODE);
		
		if (!JFile::write($data_file, $buffer))
		{
			$this->setError(JText::sprintf('COM_VMREPORTER_DIRECTORY_NOT_WRITABLE', $data_dir));
			return false;
		}
		
		return $data_file;
	}
	
	protected function cleanRow(&$item)
	{
		$item->BTasST = 1;
		
		if (!empty($item->shipto_virtuemart_order_userinfo_id))
		{
			$item->BTasST = 0;
		}
		
		unset($item->virtuemart_order_userinfo_id);
		unset($item->shipto_virtuemart_order_userinfo_id);
		
		if ($item->BTasST)
		{
			$bt_columns = VMReporterHelper::getColumns('#__virtuemart_order_userinfos', array('virtuemart_order_userinfo_id', 'virtuemart_user_id', 'address_type_name', 'created_on', 'created_by', 'address_type', 'virtuemart_order_id', 'modified_on', 'modified_by', 'locked_on', 'locked_by'));
			$bt_columns = array_merge($bt_columns, array('country_name', 'country_3_code', 'state_name'));
			
			foreach ($bt_columns as $bt_column)
			{
				$property = 'shipto_' . $bt_column;

				if (property_exists($item, $property) && !empty($item->$bt_column))
				{
					$item->$property = $item->$bt_column;
				}
			}
		}
		
		if (!empty($item->order_status_name))
		{
			$item->order_status_name = JText::_($item->order_status_name);
		}
		
		if (!empty($item->item_order_status_name))
		{
			$item->item_order_status_name = JText::_($item->item_order_status_name);
		}
		
		if (!empty($item->product_attribute))
		{
			$item->customfields = array();

			$ids     = array();
			$product = $this->product_model->getProduct($item->virtuemart_product_id);
			
			if (!empty($item->product_attribute))
			{
				$myCustoms = @json_decode($item->product_attribute,true);
				$myCustoms = (array) $myCustoms;

				foreach ($myCustoms as $custom)
				{
					if (!is_array($custom))
					{
						$custom = array( $custom =>false);
					}
					foreach ($custom as $id=>$field)
					{
						$item->customfields[] = $this->customfield_model->getCustomEmbeddedProductCustomField($id);
						$ids[] = $id;
					}
				}
			}
			
			if (!empty($product->customfields))
			{
				foreach ($product->customfields as $customfield)
				{
					if (!in_array($customfield->virtuemart_customfield_id, $ids) && $customfield->field_type == 'E' && ($customfield->is_input || $customfield->is_cart_attribute))
					{
						$item->customfields[] = $customfield;
					}
				}
			}
			
			$item->product_attribute = VirtueMartModelCustomfields::CustomsFieldOrderDisplay($item, 'BE');
			$item->product_attribute = !empty($item->product_attribute) ? trim(strip_tags($item->product_attribute)) : $item->product_attribute;
			
			unset($item->customfields);
			unset($item->customProductData);
		}
		
		$item->order_status      = JText::_($item->order_status);
		$item->item_order_status = JText::_($item->item_order_status);
		
		$item = (array) $item;
		$item = $this->sortColumns($item, $this->desired_order);
	}
	
	protected function addAliasToColumns($columns, $alias, $prefix = '')
	{
		if (!is_array($columns) || !count($columns))
		{
			$e = new JException(JText::_('JLIB_DATABASE_ERROR_COLUMNS_NOT_FOUND'));
			$this->setError($e);
			return false;
		}
		
		$db = $this->getDbo();
		
		foreach ($columns as $key => &$column)
		{
			$columns[$key] = $alias . '.' . $db->quoteName($column) . ($prefix ? ' AS ' . $db->quoteName($prefix . $column) : '');
		}
		
		return $columns;
	}
	
	public function sortColumns($report, $desired_order)
	{
		$keys          = array_keys($report);
		$desired_order = array_intersect($desired_order, $keys);
		
		return array_merge(array_flip($desired_order), $report);
	}
}
