<?php
/**
 * @package     Reporter for VirtueMart
 * 
 * @copyright   Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Abhishek Das <info@virtueplanet.com> - https://www.virtueplanet.com
 */

defined('_JEXEC') or die;

use Joomla\Registry\Registry;

jimport('joomla.filesystem.folder');

// Include missing classes and debugging function
require JPATH_ADMINISTRATOR . '/components/com_vmreporter/include.php';

class JFormRulePath extends JFormRule
{
	/**
	 * Method to test an external or internal url for all valid parts.
	 *
	 * @param   SimpleXMLElement  $element  The SimpleXMLElement object representing the `<field>` tag for the form field object.
	 * @param   mixed             $value    The form field value to validate.
	 * @param   string            $group    The field name group control value. This acts as as an array container for the field.
	 *                                      For example if the field has name="foo" and the group value is set to "bar" then the
	 *                                      full field name would end up being "bar[foo]".
	 * @param   Registry          $input    An optional Registry object with the entire data set to validate against the entire form.
	 * @param   JForm             $form     The form object for which the field is being tested.
	 *
	 * @return  boolean  True if the value is valid, false otherwise.
	 *
	 * @since   11.1
	 * @link    http://www.w3.org/Addressing/URL/url-spec.txt
	 * @see	    JString
	 */
	public function test(SimpleXMLElement $element, $value, $group = null, Registry $input = null, JForm $form = null)
	{
		// If the field is empty and not required, the field is valid.
		$required    = ((string) $element['required'] == 'true' || (string) $element['required'] == 'required');
		$requiredon  = (string) $element['requiredon'];
		$conditional = false;

		if(!empty($requiredon) && strpos($requiredon, ':') !== false)
		{
			$parts = explode(':', $requiredon);
			
			if(!$required)
			{
				$conditional = true;
			}
			
			if($input->get($parts[0]) == $parts[1])
			{
				$required = true;
			}
		}

		if(!$required && ($conditional || empty($value)))
		{
			return true;
		}
		
		if(strpos($value, '{{root}}') !== false)
		{
			$value = str_replace('{{root}}', JPATH_ROOT, $value);
		}
		
		$value = JPath::clean($value);
		
		if(($value === '') || ($value === null))
		{
			if ($element['label'])
			{
				$message = JText::_($element['label']);
			}
			else
			{
				$message = JText::_($element['name']);
			}

			$element->addAttribute('message', JText::sprintf('JLIB_FORM_VALIDATE_FIELD_REQUIRED', $message));
			
			return false;
		}
		
		if(!JFolder::exists($value) || !is_writable($value))
		{
			$element->addAttribute('message', 'File path ' . $value . ' does not exists or is not writable.');
			
			return false;
		}
		
		return true;
	}
}