<?php
/**
 * @package     Reporter for VirtueMart
 * 
 * @copyright   Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Abhishek Das <info@virtueplanet.com> - http://www.virtueplanet.com
 */

defined('_JEXEC') or die;

use Joomla\Registry\Registry;

/**
 * currency Table class
 */
class VMReporterTableReport extends JTable 
{

	/**
	* Constructor
	*
	* @param JDatabase A database connector object
	*/
	public function __construct(&$db) 
	{
		parent::__construct('#__vmreporter_reports', 'id', $db);
	}

	/**
	* Overloaded bind function to pre-process the params.
	*
	* @param  array           Named array
	* @return null|string     null is operation was satisfactory, otherwise returns an error
	* @see    JTable:bind
	* @since  1.0.0
	*/
	public function bind($array, $ignore = '') 
	{
		return parent::bind($array, $ignore);
	}

	/**
	* Method to store a node in the database table.
	*
	* @param   boolean  $updateNulls  True to update null values as well.
	*
	* @return  boolean  True on success.
	*
	* @link    http://docs.joomla.org/JTableNested/store
	* @since   1.0.0
	*/
	public function store($updateNulls = false)
	{
		$date = JFactory::getDate();
		$user = JFactory::getUser();

		if (!empty($this->data) && is_array($this->data))
		{
			$this->data = json_encode($this->data, JSON_UNESCAPED_UNICODE);
		}
		
		if (!empty($this->users_read) && is_array($this->users_read))
		{
			$registry = new Registry($this->users_read);
			$this->users_read = $registry->toString();
		}

		if (!$this->id)
		{
			// New contact. A contact created and created_by field can be set by the user,
			// so we don't touch either of these if they are set.
			if (!(int) $this->created_time)
			{
				$this->created_time = $date->toSql();
			}
			if (empty($this->created_by))
			{
				$this->created_by = $user->get('id');
			}
		}
		
		return parent::store($updateNulls);
	}
}
