<?php
/**
 * @package     Reporter for VirtueMart
 * 
 * @copyright   Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Abhishek Das <info@virtueplanet.com> - https://www.virtueplanet.com
 */

defined('_JEXEC') or die;

JHtml::addIncludePath(JPATH_COMPONENT . '/helpers/html');

if (version_compare(JVERSION, '4.0.0', 'ge'))
{
	$wa = $this->document->getWebAssetManager();
	$wa->useScript('keepalive')
		->useScript('form.validate');
}
else
{
	JHtml::_('behavior.tooltip');
	JHtml::_('formbehavior.chosen', 'select');
	JHtml::_('behavior.formvalidator');
	JHtml::_('behavior.keepalive');
}

JHtml::_('vmreporter.stylesheet', 'vmreporter/style.css');

$document = JFactory::getDocument();

$document->addScriptDeclaration("
	Joomla.submitbutton = function (task) {
		if (task == 'cron.cancel') {
			Joomla.submitform(task, document.getElementById('cron-form'));
		} else {
			if (task != 'cron.cancel' && document.formvalidator.isValid(document.getElementById('cron-form'))) {
				Joomla.submitform(task, document.getElementById('cron-form'));
			} else {
				alert('" . $this->escape(JText::_('JGLOBAL_VALIDATION_FORM_FAILED')) . "');
			}
		}
	};
");

$tabPrefix = version_compare(JVERSION, '4.0.0', 'ge') ? 'uitab' : 'bootstrap';
?>
<form action="<?php echo JRoute::_('index.php?option=com_vmreporter&view=cron&layout=edit&id=' . (int) $this->item->id); ?>" method="post" name="adminForm" id="cron-form" class="form-validate">
	
	<?php echo JLayoutHelper::render('joomla.edit.title_alias', $this); ?>

	<div class="form-horizontal">
	
		<?php echo JHtml::_($tabPrefix . '.startTabSet', 'myTab', array('active' => 'general')); ?>
		
			<?php echo JHtml::_($tabPrefix . '.addTab', 'myTab', 'general', JText::_('COM_VMREPORTER_FIELDSET_GENERAL')); ?>
				<div class="<?php echo version_compare(JVERSION, '4.0.0', 'ge') ? 'row joomla-4' : 'row-fluid'; ?>">
					<div class="span9 col-md-9">
						<fieldset class="adminform pt-2">
							<?php echo $this->form->renderField('template_id'); ?>
							<?php echo $this->form->renderField('start_time'); ?>
							<?php echo $this->form->renderField('once_only'); ?>
							<?php echo $this->form->renderField('send_mail'); ?>
							<?php echo $this->form->renderField('email_ids'); ?>
							<?php echo $this->form->renderField('time_interval_uom'); ?>
							<?php echo $this->form->renderField('minutes'); ?>
							<?php echo $this->form->renderField('hours'); ?>
							<?php echo $this->form->renderField('days'); ?>
							<?php echo $this->form->renderField('weeks'); ?>
							<?php echo $this->form->renderField('months'); ?>
							<?php echo $this->form->renderField('next_run_time'); ?>
							<?php echo $this->form->renderField('last_run_time'); ?>
						</fieldset>
					</div>
					<div class="span3 col-md-3">
						<div class="form-vertical">
							<?php echo $this->form->renderField('id'); ?>
							<?php echo $this->form->renderField('state'); ?>
							<?php echo $this->form->renderField('created_by'); ?>
							<?php echo $this->form->renderField('created_on'); ?>
							<?php echo $this->form->renderField('modified_by'); ?>
							<?php echo $this->form->renderField('modified_on'); ?>
							<?php if($this->item->id) : ?>
								<?php echo $this->form->renderField('hits'); ?>
							<?php endif; ?>
							<?php if(!empty($this->item->currently_running)) : ?>
								<?php echo $this->form->renderField('currently_running'); ?>
							<?php endif; ?>
						</div>
					</div>
				</div>
			<?php echo JHtml::_($tabPrefix . '.endTab'); ?>
			
			<?php if(!empty($this->item->log)) : ?>
				<?php echo JHtml::_($tabPrefix . '.addTab', 'myTab', 'log', JText::_('COM_VMREPORTER_FIELDSET_LOG')); ?>
					<div class="<?php echo version_compare(JVERSION, '4.0.0', 'ge') ? 'row' : 'row-fluid'; ?>">
						<div class="span12 col">
							<table class="table table-bordered">
								<thead>
									<tr>
										<th width="1%">#</th>
										<th>Details</th>
										<th width="10%">Date</th>
									</tr>
								</thead>
								<tbody>
									<?php foreach($this->item->log as $key => $log) : ?>
										<tr class="<?php echo $log['success'] ? 'success' : 'error'; ?>">
											<td><?php echo $key + 1; ?></td>
											<td><?php echo JText::_($log['message']); ?></td>
											<td><?php echo $log['time'] > 0 ? JHtml::_('date', $log['time'], JText::_('DATE_FORMAT_LC5')) : '-'; ?></td>
										</tr>
									<?php endforeach; ?>
								</tbody>
							</table>
						</div>
					</div>
				<?php echo JHtml::_($tabPrefix . '.endTab'); ?>
			<?php endif; ?>
			
		<?php echo JHtml::_($tabPrefix . '.endTabSet'); ?>
		
		<input type="hidden" name="task" value="" />
		<?php echo JHtml::_('form.token'); ?>
	</div>
</form>
