<?php
/**
 * @package     Reporter for VirtueMart
 * 
 * @copyright   Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Abhishek Das <info@virtueplanet.com> - https://www.virtueplanet.com
 */

defined('_JEXEC') or die;

JHtml::addIncludePath(JPATH_COMPONENT . '/helpers/html');

JHtml::_('jquery.framework');
JHtml::_('bootstrap.tooltip');
JHtml::_('behavior.keepalive');
JHtml::_('behavior.formvalidator');

JHtml::_('vmreporter.stylesheet', 'vmreporter/style.css');

JHtml::_('vmreporter.script', 'vmreporter/jquery.flot.min.js');
JHtml::_('vmreporter.script', 'vmreporter/jquery.flot.pie.min.js');
JHtml::_('vmreporter.script', 'vmreporter/jquery.flot.time.min.js');
JHtml::_('vmreporter.script', 'vmreporter/jquery.flot.tooltip.min.js');
JHtml::_('vmreporter.script', 'vmreporter/jquery.flot.resize.js');
JHtml::_('vmreporter.script', 'vmreporter/base.min.js');
JHtml::_('vmreporter.script', 'vmreporter/frontpage.js');

VMReporterScript::addOption('ROOT', JUri::root());
VMReporterScript::addOption('BASE', JUri::base());
VMReporterScript::addOption('IS_GUEST_INFO', JText::_('COM_VMREPORTER_IS_GUEST_USER'));
VMReporterScript::addOption('CURRENCY_FORMAT', $this->currency_format);
VMReporterScript::addOption('CHART_OVERVIEW_DATA', (!empty($this->data->overview) ? $this->data->overview : array()));
VMReporterScript::addOption('CHART_PRODUCT_DATA', $this->product_data);
VMReporterScript::addOption('CHART_CATEGORY_DATA', $this->category_data);
VMReporterScript::addOption('CHART_CUSTOMER_DATA', $this->customer_data);
?>
<form action="<?php echo JRoute::_('index.php?option=com_vmreporter&view=frontpage'); ?>" method="post" name="adminForm" id="vmreporter-frontpage-form">
<?php if (version_compare(JVERSION, '4.0.0', 'lt') && !empty( $this->sidebar)) : ?>
	<div id="j-sidebar-container" class="span2">
		<?php echo $this->sidebar; ?>
	</div>
	<div id="j-main-container" class="span10">
<?php else : ?>
	<div id="j-main-container">
<?php endif; ?>
		<div class="vmreporter-frontpage">
			<div class="js-stools frontpage-toolbar clearfix">
				<div class="clearfix">
					<div class="js-stools-container-bar">
						<div class="field-group">
							<label for="filter_statuses"><?php echo JText::_('COM_VMREPORTER_FORM_LBL_STATUES'); ?></label>
							<?php echo JHtml::_('vmreporter.orderstatuses', 'filter_status[]', 'filter_status', '', $this->statuses); ?>
						</div>
						<div class="field-group">
							<label for="filter_period"><?php echo JText::_('COM_VMREPORTER_FORM_LBL_PERIOD'); ?></label>
							<?php echo JHtml::_('vmreporter.periods', 'filter_period', 'filter_period', ' class="form-select"', $this->period); ?>
						</div>
						<div class="field-group">
							<label for="filter_start_date"><?php echo JText::_('COM_VMREPORTER_FORM_LBL_TEMPLATE_START_DATE'); ?></label>
							<?php echo JHtml::_('vmreporter.calendar', $this->start_date, 'filter_start_date', 'filter_start_date'); ?>
						</div>
						<div class="field-group">
							<label for="filter_end_date"><?php echo JText::_('COM_VMREPORTER_FORM_LBL_TEMPLATE_END_DATE'); ?></label>
							<?php echo JHtml::_('vmreporter.calendar', $this->end_date, 'filter_end_date', 'filter_end_date'); ?>
						</div>
					</div>
				</div>
			</div>
			
			<div id="vm-reporter-chart">
				<h3><?php echo JText::_('COM_VMREPORTER_FRONTPAGE_OVERVIEW'); ?></h3>
				<div class="vmreporter-chart-container">
					<?php echo JHtml::_('bootstrap.startTabSet', 'reporterOverview', array('active' => 'revenue')); ?>
						
						<?php $order_total = !empty($this->data->order_total) ? $this->data->order_total : 0; ?>
						<?php echo JHtml::_('bootstrap.addTab', 'reporterOverview', 'revenue', JText::_('COM_VMREPORTER_TAB_REVENUE') . '<span>' . $this->currency->priceDisplay($order_total) . '</span>'); ?>
							<div id="vmreporter-overview-revenue" class="vmreporter-placeholder">
								<?php echo empty($this->data) ? ('<div class="no-data">' . JText::_('COM_VMREPORTER_NO_DATA_FOUND') . '</div>') : ''; ?>
							</div>
						<?php echo JHtml::_('bootstrap.endTab'); ?>
						
						<?php $order_count = !empty($this->data->order_count) ? $this->data->order_count : 0; ?>
						<?php echo JHtml::_('bootstrap.addTab', 'reporterOverview', 'count', JText::_('COM_VMREPORTER_TAB_ORDERS') . '<span>' . $order_count . '</span>'); ?>
							<div id="vmreporter-overview-count" class="vmreporter-placeholder">
								<?php echo empty($this->data) ? ('<div class="no-data">' . JText::_('COM_VMREPORTER_NO_DATA_FOUND') . '</div>') : ''; ?>
							</div>
						<?php echo JHtml::_('bootstrap.endTab'); ?>
					
					<?php echo JHtml::_('bootstrap.endTabSet'); ?>
				</div>

				<h3><?php echo JText::_('COM_VMREPORTER_FRONTPAGE_PRODUCTS'); ?></h3>
				<div class="vmreporter-chart-container">
					<?php echo JHtml::_('bootstrap.startTabSet', 'reporterProducts', array('active' => 'total')); ?>
					
						<?php echo JHtml::_('bootstrap.addTab', 'reporterProducts', 'total', JText::_('COM_VMREPORTER_TAB_BY_ORDER_VALUE')); ?>
							<div id="vmreporter-product-total" class="vmreporter-placeholder">
								<?php echo empty($this->data) ? ('<div class="no-data">' . JText::_('COM_VMREPORTER_NO_DATA_FOUND') . '</div>') : ''; ?>
							</div>
							<?php if(!empty($this->data->order_total)) : ?>
								<div id="vmreporter-product-total-legends" class="chart-legend"></div>
							<?php endif; ?>
						<?php echo JHtml::_('bootstrap.endTab'); ?>
						
						<?php echo JHtml::_('bootstrap.addTab', 'reporterProducts', 'product-order-count', JText::_('COM_VMREPORTER_TAB_BY_ORDER_COUNT')); ?>
							<div id="vmreporter-product-count" class="vmreporter-placeholder">
								<?php echo empty($this->data) ? ('<div class="no-data">' . JText::_('COM_VMREPORTER_NO_DATA_FOUND') . '</div>') : ''; ?>
							</div>
							<?php if(!empty($this->data->order_total)) : ?>
								<div id="vmreporter-product-count-legends" class="chart-legend"></div>
							<?php endif; ?>
						<?php echo JHtml::_('bootstrap.endTab'); ?>
						
						<?php echo JHtml::_('bootstrap.addTab', 'reporterProducts', 'quantity', JText::_('COM_VMREPORTER_TAB_BY QUANTITY')); ?>
							<div id="vmreporter-product-quantity" class="vmreporter-placeholder">
								<?php echo empty($this->data) ? ('<div class="no-data">' . JText::_('COM_VMREPORTER_NO_DATA_FOUND') . '</div>') : ''; ?>
							</div>
							<?php if(!empty($this->data->order_total)) : ?>
								<div id="vmreporter-product-quantity-legends" class="chart-legend"></div>
							<?php endif; ?>
						<?php echo JHtml::_('bootstrap.endTab'); ?>
						
						<?php echo JHtml::_('bootstrap.addTab', 'reporterProducts', 'revenues', JText::_('COM_VMREPORTER_TAB_BY REVENUES')); ?>
							<div id="vmreporter-product-revenue" class="vmreporter-placeholder">
								<?php echo empty($this->data) ? ('<div class="no-data">' . JText::_('COM_VMREPORTER_NO_DATA_FOUND') . '</div>') : ''; ?>
							</div>
							<?php if(!empty($this->data->order_total)) : ?>
								<div id="vmreporter-product-revenue-legends" class="chart-legend"></div>
							<?php endif; ?>
						<?php echo JHtml::_('bootstrap.endTab'); ?>
					
					<?php echo JHtml::_('bootstrap.endTabSet'); ?>
				</div>

				<h3><?php echo JText::_('COM_VMREPORTER_FRONTPAGE_CATEGORIES'); ?></h3>
				<div class="vmreporter-chart-container">
					<?php echo JHtml::_('bootstrap.startTabSet', 'reporterCategories', array('active' => 'cat-total')); ?>
					
						<?php echo JHtml::_('bootstrap.addTab', 'reporterCategories', 'cat-total', JText::_('COM_VMREPORTER_TAB_BY_ORDER_VALUE')); ?>
							<div id="vmreporter-category-total" class="vmreporter-placeholder">
								<?php echo empty($this->data) ? ('<div class="no-data">' . JText::_('COM_VMREPORTER_NO_DATA_FOUND') . '</div>') : ''; ?>
							</div>
							<?php if(!empty($this->data->order_total)) : ?>
								<div id="vmreporter-category-total-legends" class="chart-legend"></div>
							<?php endif; ?>
						<?php echo JHtml::_('bootstrap.endTab'); ?>
						
						<?php echo JHtml::_('bootstrap.addTab', 'reporterCategories', 'cat-count', JText::_('COM_VMREPORTER_TAB_BY_ORDER_COUNT')); ?>
							<div id="vmreporter-category-count" class="vmreporter-placeholder">
								<?php echo empty($this->data) ? ('<div class="no-data">' . JText::_('COM_VMREPORTER_NO_DATA_FOUND') . '</div>') : ''; ?>
							</div>
							<?php if(!empty($this->data->order_total)) : ?>
								<div id="vmreporter-category-count-legends" class="chart-legend"></div>
							<?php endif; ?>
						<?php echo JHtml::_('bootstrap.endTab'); ?>
						
						<?php echo JHtml::_('bootstrap.addTab', 'reporterCategories', 'cat-quantity', JText::_('COM_VMREPORTER_TAB_BY QUANTITY')); ?>
							<div id="vmreporter-category-quantity" class="vmreporter-placeholder">
								<?php echo empty($this->data) ? ('<div class="no-data">' . JText::_('COM_VMREPORTER_NO_DATA_FOUND') . '</div>') : ''; ?>
							</div>
							<?php if(!empty($this->data->order_total)) : ?>
								<div id="vmreporter-category-quantity-legends" class="chart-legend"></div>
							<?php endif; ?>
						<?php echo JHtml::_('bootstrap.endTab'); ?>
						
						<?php echo JHtml::_('bootstrap.addTab', 'reporterCategories', 'cat-revenues', JText::_('COM_VMREPORTER_TAB_BY REVENUES')); ?>
							<div id="vmreporter-category-revenue" class="vmreporter-placeholder">
								<?php echo empty($this->data) ? ('<div class="no-data">' . JText::_('COM_VMREPORTER_NO_DATA_FOUND') . '</div>') : ''; ?>
							</div>
							<?php if(!empty($this->data->order_total)) : ?>
								<div id="vmreporter-category-revenue-legends" class="chart-legend"></div>
							<?php endif; ?>
						<?php echo JHtml::_('bootstrap.endTab'); ?>
					
					<?php echo JHtml::_('bootstrap.endTabSet'); ?>
				</div>
				
				<h3><?php echo JText::_('COM_VMREPORTER_FRONTPAGE_CUSTOMERS'); ?></h3>
				<div class="vmreporter-chart-container">
					<?php echo JHtml::_('bootstrap.startTabSet', 'reporterCustomers', array('active' => 'customer-total')); ?>
					
						<?php echo JHtml::_('bootstrap.addTab', 'reporterCustomers', 'customer-total', JText::_('COM_VMREPORTER_TAB_BY_ORDER_VALUE')); ?>
							<div id="vmreporter-customer-total" class="vmreporter-placeholder">
								<?php echo empty($this->data) ? ('<div class="no-data">' . JText::_('COM_VMREPORTER_NO_DATA_FOUND') . '</div>') : ''; ?>
							</div>
							<?php if(!empty($this->data->order_total)) : ?>
								<div id="vmreporter-customer-total-legends" class="chart-legend"></div>
							<?php endif; ?>
						<?php echo JHtml::_('bootstrap.endTab'); ?>
						
						<?php echo JHtml::_('bootstrap.addTab', 'reporterCustomers', 'customer-count', JText::_('COM_VMREPORTER_TAB_BY_ORDER_COUNT')); ?>
							<div id="vmreporter-customer-count" class="vmreporter-placeholder">
								<?php echo empty($this->data) ? ('<div class="no-data">' . JText::_('COM_VMREPORTER_NO_DATA_FOUND') . '</div>') : ''; ?>
							</div>
							<?php if(!empty($this->data->order_total)) : ?>
								<div id="vmreporter-customer-count-legends" class="chart-legend"></div>
							<?php endif; ?>
						<?php echo JHtml::_('bootstrap.endTab'); ?>
						
						<?php echo JHtml::_('bootstrap.addTab', 'reporterCustomers', 'customer-revenues', JText::_('COM_VMREPORTER_TAB_BY REVENUES')); ?>
							<div id="vmreporter-customer-revenue" class="vmreporter-placeholder">
								<?php echo empty($this->data) ? ('<div class="no-data">' . JText::_('COM_VMREPORTER_NO_DATA_FOUND') . '</div>') : ''; ?>
							</div>
							<?php if(!empty($this->data->order_total)) : ?>
								<div id="vmreporter-customer-revenue-legends" class="chart-legend"></div>
							<?php endif; ?>
						<?php echo JHtml::_('bootstrap.endTab'); ?>
					
					<?php echo JHtml::_('bootstrap.endTabSet'); ?>
				</div>
			</div>
			
			<div class="vmreporter-loader-overlay"></div>
			<div class="vmreporter-loader">
				<div class="loader--dot"></div>
				<div class="loader--dot"></div>
				<div class="loader--dot"></div>
				<div class="loader--dot"></div>
				<div class="loader--dot"></div>
				<div class="loader--dot"></div>
				<div class="loader--text"></div>
			</div>
		</div>
		<?php echo JHtml::_('form.token'); ?>
	</div>
	<?php echo VMReporterScript::getOptions(); ?>
</form>