<?php
/**
 * @package     Reporter for VirtueMart
 * 
 * @copyright   Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Abhishek Das <info@virtueplanet.com> - https://www.virtueplanet.com
 */

defined('_JEXEC') or die;

class VmreporterViewFrontPage extends JViewLegacy
{
	protected $state;
	protected $items;
	protected $report;
	protected $report_template;
	protected $data;
	protected $product_data;
	protected $category_data;
	protected $customer_data;
	protected $currency;
	protected $currency_format;
	protected $start_date;
	protected $end_date;
	protected $statuses;
	protected $period;
	
	/**
	 * Display the view
	 */
	public function display($tpl = null)
	{
		$this->state           = $this->get('State');
		$this->report          = $this->get('Report');
		$this->items           = $this->get('Items');
		$this->report_template = $this->get('ReportTemplate');
		$this->data            = $this->get('Data');
		$this->product_data    = $this->get('ProductData');
		$this->category_data   = $this->get('CategoryData');
		$this->customer_data   = $this->get('CustomerData');
		$this->currency        = CurrencyDisplay::getInstance();
		$this->currency_format = VMReporterHelper::getCurrencyFormat();
		$this->period          = $this->state->get('report.period');
		$this->statuses        = $this->state->get('report.status');
		$this->start_date      = $this->state->get('report.start_date');
		$this->end_date        = $this->state->get('report.end_date');
		
		// Check for errors.
		if (count($errors = $this->get('Errors')))
		{
			throw new Exception(implode("\n", $errors));
		}

		$this->addToolbar();
		
		VMReporterHelper::addSubmenu('frontpage');

		$this->sidebar = JHtmlSidebar::render();
		
		parent::display($tpl);
	}

	/**
	 * Add the page title and toolbar.
	 */
	protected function addToolbar()
	{
		$canDo = VMReporterHelper::getActions();
		
		// Get the toolbar object instance
		$bar = JToolbar::getInstance('toolbar');

		JToolbarHelper::title(JText::_('COM_VMREPORTER') . ': ' . JText::_('COM_VMREPORTER_MENU_TITLE_OVERVIEW'), 'bars article');
		
		if (!empty($this->data))
		{
			JToolbarHelper::link(JRoute::_('index.php?option=com_vmreporter&task=frontpage.download&' . JSession::getFormToken() . '=1'), JText::_('COM_VMREPORTER_DOWNLOAD'), 'download');
		}

		if ($canDo->get('core.admin'))
		{
			JToolBarHelper::preferences('com_vmreporter');
		}
	}
}
