<?php
/**
 * @package     Reporter for VirtueMart
 * 
 * @copyright   Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Abhishek Das <info@virtueplanet.com> - https://www.virtueplanet.com
 */

defined('_JEXEC') or die;

JHtml::addIncludePath(JPATH_COMPONENT . '/helpers/html');

JHtml::_('jquery.framework');
JHtml::_('bootstrap.tooltip');
JHtml::_('behavior.keepalive');
JHtml::_('behavior.formvalidator');

if (!version_compare(JVERSION, '4.0.0', 'ge'))
{
	JHtml::_('behavior.multiselect');
	JHtml::_('formbehavior.chosen', '.multipleCategories', null, array('placeholder_text_multiple' => JText::_('COM_VMREPORTER_SELECT_CATEGORY')));
	JHtml::_('formbehavior.chosen', '.multipleManufacturers', null, array('placeholder_text_multiple' => JText::_('COM_VMREPORTER_SELECT_MANUFACTURER')));
	JHtml::_('formbehavior.chosen', 'select');
}

JHtml::_('vmreporter.stylesheet', 'vmreporter/style.css');

$user        = JFactory::getUser();
$listOrder   = $this->escape($this->state->get('list.ordering'));
$listDirn    = $this->escape($this->state->get('list.direction'));
$date_format = $this->params->get('date_format', 0) ? 'DATE_FORMAT_LC4' : 'DATE_FORMAT_LC5';
?>
<form action="<?php echo JRoute::_('index.php?option=com_vmreporter&view=inventory'); ?>" method="post" name="adminForm" id="adminForm">
<?php if (!version_compare(JVERSION, '4.0.0', 'ge') && !empty( $this->sidebar)) : ?>
	<div id="j-sidebar-container" class="span2">
		<?php echo $this->sidebar; ?>
	</div>
	<div id="j-main-container" class="span10">
<?php else : ?>
	<div id="j-main-container">
<?php endif; ?>
		<?php
		// Search tools bar
		echo JLayoutHelper::render('joomla.searchtools.default', array('view' => $this));
		?>
		<?php if (empty($this->items)) : ?>
			<div class="alert alert-no-items">
				<?php echo JText::_('JGLOBAL_NO_MATCHING_RESULTS'); ?>
			</div>
		<?php else : ?>
			<table class="table table-striped" id="reportList">
				<thead>
					<tr>
						<th>
							<?php echo JHtml::_('searchtools.sort', 'COM_VIRTUEMART_PRODUCT_NAME', 'product_name', $listDirn, $listOrder); ?>
						</th>
						<th class="hidden-phone">
							<?php echo JHtml::_('searchtools.sort',  'COM_VIRTUEMART_PRODUCT_CHILDREN_OF', 'parent_product_name', $listDirn, $listOrder); ?>
						</th>
						<th class="center text-center">
							<?php echo JHtml::_('searchtools.sort',  'COM_VIRTUEMART_PRODUCT_SKU', 'p.product_sku', $listDirn, $listOrder); ?>
						</th>
						<th width="1%" class="hidden-phone center text-center nowrap">
							<?php echo JHtml::_('searchtools.sort', 'COM_VIRTUEMART_PRODUCT_FORM_IN_STOCK', 'product_in_stock', $listDirn, $listOrder); ?>
						</th>
						<th width="1%" class="hidden-phone center nowrap">
							<?php echo JHtml::_('searchtools.sort', 'COM_VIRTUEMART_PRODUCT_FORM_ORDERED_STOCK', 'product_ordered', $listDirn, $listOrder); ?>
						</th>
						<th width="1%" class="center text-center nowrap">
							<?php echo JHtml::_('searchtools.sort', 'COM_VMREPORTER_AVAILABLE_STOCK', 'available_stock', $listDirn, $listOrder); ?>
						</th>
						<th width="1%" class="center text-center">
							<?php echo JHtml::_('searchtools.sort', 'COM_VIRTUEMART_PRODUCT_FORM_SPECIAL', 'p.product_special', $listDirn, $listOrder); ?>
						</th>
						<th width="1%" class="center text-center">
							<?php echo JHtml::_('searchtools.sort', 'COM_VIRTUEMART_PUBLISHED', 'p.published', $listDirn, $listOrder); ?>
						</th>
						<th width="1%">
							<?php echo JHtml::_('searchtools.sort', 'COM_VIRTUEMART_ID', 'p.virtuemart_product_id', $listDirn, $listOrder); ?>
						</th>
					</tr>
				</thead>
				<tfoot>
					<tr>
						<td colspan="9"></td>
					</tr>
				</tfoot>
				<tbody>
				<?php foreach ($this->items as $i => $item) :
					$item->max_ordering = 0;
					$ordering   = ($listOrder == 'a.ordering');
					
					if (empty($item->product_name))
					{
						$item->product_name = vmText::sprintf('COM_VM_TRANSLATION_MISSING', 'virtuemart_product_id', $item->virtuemart_product_id);
					}
					
					if ($item->product_parent_id > 0 && empty($item->parent_product_name))
					{
						$item->parent_product_name = vmText::sprintf('COM_VM_TRANSLATION_MISSING', 'virtuemart_product_id', $item->product_parent_id);
					}
					?>
					<tr class="row<?php echo $i % 2; ?>">
						<td class="has-context">
							<div class="pull-left break-word">
								<a class="hasTooltip" href="<?php echo JRoute::_('index.php?option=com_virtuemart&view=product&task=edit&virtuemart_product_id=' . (int) $item->virtuemart_product_id); ?>" target="_blank">
									<span><?php echo $item->product_name; ?></span>
								</a>
								<div class="categories small">
									<?php echo vmText::_('COM_VIRTUEMART_CATEGORY'); ?>: <?php echo JHtml::_('vmreporter.categories', $item->virtuemart_product_id); ?>
								</div>
								<div class="manufacturers small">
									<?php echo vmText::_('COM_VIRTUEMART_MANUFACTURER_S'); ?>: <?php echo JHtml::_('vmreporter.manufacturers', $item->virtuemart_product_id); ?>
								</div>
							</div>
						</td>
						<td class="hidden-phone small">
							<?php if ($item->product_parent_id > 0) : ?>
								<a class="hasTooltip" href="<?php echo JRoute::_('index.php?option=com_vmreporter&view=inventory&parent_product_id=' . (int) $item->product_parent_id); ?>">
									<span><?php echo $item->parent_product_name; ?></span>
								</a>
							<?php endif; ?>
						</td>
						<td class="center text-center small">
							<?php echo $item->product_sku; ?>
						</td>
						<td class="hidden-phone center text-center">
							<span class="badge badge-info bg-info"><?php echo (int) $item->product_in_stock; ?></span>
						</td>
						<td class="hidden-phone center text-center">
							<span class="badge badge-warning bg-warning"><?php echo (int) $item->product_ordered; ?></span>
						</td>
						<td class="center text-center">
							<?php if ($item->available_stock > 0) : ?>
								<span class="badge badge-success bg-success"><?php echo (int) $item->available_stock; ?></span>
							<?php else : ?>
								<span class="badge badge-danger badge-important bg-danger"><?php echo (int) $item->available_stock; ?></span>
							<?php endif; ?>
						</td>
						<td class="center text-center">
							<?php if ($item->product_special) : ?>
								<span class="icon-featured text-warning"></span>
							<?php else : ?>
								<span class="icon-unfeatured text-muted"></span>
							<?php endif; ?>
						</td>
						<td class="center text-center">
							<?php if ($item->published) : ?>
								<span class="icon-publish text-success"></span>
							<?php else : ?>
								<span class="icon-unpublish text-danger"></span>
							<?php endif; ?>
						</td>
						<td>
							<?php echo $item->virtuemart_product_id; ?>
						</td>
					</tr>
					<?php endforeach; ?>
				</tbody>
			</table>
		<?php endif; ?>

		<?php echo $this->pagination->getListFooter(); ?>
		
		<input type="hidden" name="task" value="" />
		<input type="hidden" name="boxchecked" value="0" />
		<?php echo JHtml::_('form.token'); ?>
</div>
</form>