<?php
/**
 * @package     Reporter for VirtueMart
 * 
 * @copyright   Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Abhishek Das <info@virtueplanet.com> - https://www.virtueplanet.com
 */

defined('_JEXEC') or die;

/**
 * View class for a list of inventory.
 */
class VMReporterViewInventory extends JViewLegacy
{
	/**
	 * An array of items
	 *
	 * @var  array
	 */
	protected $items;

	/**
	 * The pagination object
	 *
	 * @var  JPagination
	 */
	protected $pagination;

	/**
	 * The model state
	 *
	 * @var  object
	 */
	protected $state;

	/**
	 * Form object for search filters
	 *
	 * @var  JForm
	 */
	public $filterForm;

	/**
	 * The active search filters
	 *
	 * @var  array
	 */
	public $activeFilters;
	
	public $params;

	/**
	 * The sidebar markup
	 *
	 * @var  string
	 */
	protected $sidebar;

	/**
	 * Display the view
	 */
	public function display($tpl = null)
	{
		$this->state         = $this->get('State');
		$this->items         = $this->get('Items');
		$this->pagination    = $this->get('Pagination');
		$this->filterForm    = $this->get('FilterForm');
		$this->activeFilters = $this->get('ActiveFilters');
		$this->params        = $this->state->get('params');

		// Check for errors.
		if (count($errors = $this->get('Errors')))
		{
			throw new Exception(implode("\n", $errors));
		}
		
		$this->addToolbar();
		
		VMReporterHelper::addSubmenu('inventory');

		$this->sidebar = JHtmlSidebar::render();
		
		parent::display($tpl);
	}

	protected function addToolbar()
	{
		$app   = JFactory::getApplication();
		$user  = JFactory::getUser();
		$canDo = VMReporterHelper::getActions();
		
		// Get the toolbar object instance
		$bar = JToolbar::getInstance('toolbar');

		JToolbarHelper::title(JText::_('COM_VMREPORTER_TITLE_INVENTORY'), 'list article');

		if (!empty($this->items))
		{
			JToolbarHelper::link(JRoute::_('index.php?option=com_vmreporter&task=inventory.download&' . JSession::getFormToken() . '=1'), JText::_('COM_VMREPORTER_DOWNLOAD'), 'download');
			
			if ($app->getUserState('com_vmreporter.inventory.filter.parent_product_id', 0))
			{
				JToolbarHelper::custom('inventory.reset', 'unpublish', 'reset', 'COM_VMREPORTER_RESET_PARENT', false);
			}
		}

		if ($canDo->get('core.admin'))
		{
			JToolBarHelper::preferences('com_vmreporter');
		}
	}
}
