<?php
/**
 * @package     Reporter for VirtueMart
 * 
 * @copyright   Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Abhishek Das <info@virtueplanet.com> - https://www.virtueplanet.com
 */

defined('_JEXEC') or die;

$date_format = $this->params->get('date_format', 0) ? 'DATE_FORMAT_LC4' : 'DATE_FORMAT_LC5';
?>
<div id="vm-reporter-chart" ng-controller="chart">
	<div class="vmreporter-header">
		<h2>
			<a href="<?php echo JRoute::_('index.php?option=com_vmreporter&task=template.edit&id=' . $this->report_template->id); ?>" target="_blank">
				<?php echo $this->escape($this->report_template->name); ?>&nbsp;<i class="icon-out-2"></i></a>
		</h2>
		<ul class="vmreporter-report-details">
			<li>
				<span class="vmreporter-title"><?php echo JText::_('COM_VMREPORTER_LBL_CREATED_ON'); ?></span>
				<span><?php echo $this->report->created_time > 0 ? JHtml::_('date', $this->report->created_time, JText::_('DATE_FORMAT_LC5')) : '-'; ?></span>
			</li>
			<li>
				<span class="vmreporter-title"><?php echo JText::_('COM_VMREPORTER_LBL_ORDER_TOTAL'); ?></span>
				<span><?php echo $this->currency->priceDisplay($this->data->order_total); ?></span>
			</li>
			<li>
				<span class="vmreporter-title"><?php echo JText::_('COM_VMREPORTER_LBL_CHART_ORDER_COUNT'); ?></span>
				<span class="badge badge-info bg-info"><?php echo $this->data->order_count; ?></span>
			</li>
			<li>
				<span class="vmreporter-title"><?php echo JText::_('COM_VMREPORTER_FORM_LBL_TEMPLATE_START_DATE'); ?></span>
				<span><?php echo $this->start_date > 0 ? JHtml::_('date', $this->start_date, JText::_($date_format), null) : '-'; ?></span>
			</li>
			<li>
				<span class="vmreporter-title"><?php echo JText::_('COM_VMREPORTER_FORM_LBL_TEMPLATE_END_DATE'); ?></span>
				<span><?php echo $this->end_date > 0 ? JHtml::_('date', $this->end_date, JText::_($date_format), null) : '-'; ?></span>
			</li>
			<li>
				<span class="vmreporter-title"><?php echo JText::_('COM_VMREPORTER_FORM_LBL_TIME_FIELD'); ?></span>
				<span><?php echo !empty($this->report->time_field) ? JText::_('COM_VMREPORTER_LBL_' . strtoupper($this->report->time_field)) : JText::_('COM_VMREPORTER_LBL_CREATED_ON'); ?></span>
			</li>
		</ul>
	</div>
	<div class="vmreporter-chart-section">
		<div class="vmreporter-toolbar">
			<div class="vmreporter-toolbar-inner clearfix">

				<div class="vmreporter-toolbar-element last-element">
					<label for="chart-type" class="sr-only element-invisible"><?php echo JText::_('COM_VMREPORTER_LBL_CHART_TYPE'); ?></label>
					<select class="form-select" ng-model="chartType" ng-init="chartType='overview'" ng-change="updateChart()" id="chart-type">
						<option value="overview"><?php echo JText::_('COM_VMREPORTER_CHART_TYPE_OVERVIEW'); ?></option>
						<option value="virtuemart_product_id"><?php echo JText::_('COM_VMREPORTER_CHART_TYPE_PRODUCT'); ?></option>
						<option value="category_id"><?php echo JText::_('COM_VMREPORTER_CHART_TYPE_CATEGORY'); ?></option>
						<option value="customer_number"><?php echo JText::_('COM_VMREPORTER_CHART_TYPE_CUSTOMER'); ?></option>
						<option value="virtuemart_shipmentmethod_id"><?php echo JText::_('COM_VMREPORTER_CHART_TYPE_SHIPMENT'); ?></option>
						<option value="virtuemart_paymentmethod_id"><?php echo JText::_('COM_VMREPORTER_CHART_TYPE_PAYMENT'); ?></option>
						<option value="order_status"><?php echo JText::_('COM_VMREPORTER_CHART_TYPE_STATUS'); ?></option>
					</select>
				</div>
				
				<div class="vmreporter-toolbar-element last-element ng-hide" ng-hide="chartType == 'overview'">
					<label for="chart-content" class="sr-only element-invisible"><?php echo JText::_('COM_VMREPORTER_LBL_CHART_CONTENT'); ?></label>
					<select class="form-select" ng-model="chartContent" ng-init="chartContent='order_totals'" ng-change="updateChart()" id="chart-content">
						<option value="order_totals"><?php echo JText::_('COM_VMREPORTER_CHART_CONTENT_TOTALS'); ?></option>
						<option value="item_order_counts"><?php echo JText::_('COM_VMREPORTER_CHART_CONTENT_COUNTS'); ?></option>
						<option value="order_counts"><?php echo JText::_('COM_VMREPORTER_CHART_CONTENT_QUANTITY'); ?></option>
						<option value="revenues"><?php echo JText::_('COM_VMREPORTER_CHART_CONTENT_REVENUES'); ?></option>
					</select>
				</div>
				
			</div>
		</div>
		<div class="vmreporter-chart-container" ng-init="initChart()">
			<div class="vmreporter-chart-content chart-overview" ng-hide="chartType != 'overview'">
				<div id="vmreporter-overview-chart" class="vmreporter-placeholder"></div>
			</div>
			<div class="vmreporter-chart-content chart-breakup ng-hide" ng-hide="chartType == 'overview'">
				<div id="vmreporter-analysis-chart" class="vmreporter-placeholder"></div>
				<div id="vmreporter-analysis-legends" class="chart-legend"></div>
				<div class="vmreporter-loader-overlay"></div>
				<div class="vmreporter-loader">
					<div class="loader--dot"></div>
					<div class="loader--dot"></div>
					<div class="loader--dot"></div>
					<div class="loader--dot"></div>
					<div class="loader--dot"></div>
					<div class="loader--dot"></div>
					<div class="loader--text"></div>
				</div>
			</div>
		</div>
	</div>
</div>
