<?php
/**
 * @package     Reporter for VirtueMart
 * 
 * @copyright   Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Abhishek Das <info@virtueplanet.com> - https://www.virtueplanet.com
 */

defined('_JEXEC') or die;

$sortFields = $this->getSortFields();
?>
<div class="bs-component" ng-controller="listdata">
	<div class="vmreporter-toolbar">
		<form>
			<div class="vmreporter-toolbar-inner clearfix">
				<div class="vmreporter-toolbar-element">
					<label for="report-search" class="sr-only element-invisible"><?php echo JText::_('COM_VMREPORTER_LBL_FILTER_SEARCH'); ?></label>
					<input type="text" ng-model="search" id="report-search" class="form-control" placeholder="<?php echo JText::_('COM_VMREPORTER_SEARCH_REPORT'); ?>" />
				</div>
				
				<?php if($this->unqiueOrdersOnly) : ?>
					<input type="hidden" ng-model="uniqueOnly" ng-init="uniqueOnly='1'" value="1" />
				<?php else : ?>
					<div class="vmreporter-toolbar-element">
						<label for="unique-only" class="sr-only element-invisible"><?php echo JText::_('COM_VMREPORTER_LBL_FILTER_UNIQUE'); ?></label>
						<select class="form-select" ng-model="uniqueOnly" ng-init="uniqueOnly=''" ng-change="update()" id="unique-only">
							<option value=""><?php echo JText::_('COM_VMREPORTER_FILTER_UNIQUE'); ?></option>
							<option value="0"><?php echo JText::_('JNO'); ?></option>
							<option value="1"><?php echo JText::_('JYES'); ?></option>
						</select>
					</div>
				<?php endif; ?>
				
				<div class="vmreporter-toolbar-element" ng-if="hasHiddenColumns">
					<button type="button" class="btn btn-info hasTooltip" ng-if="hasHiddenColumns" ng-click="unhide()" title="<?php echo JText::_('COM_VMREPORTER_TITLE_UNHIDE_COLUMNS'); ?>"><?php echo JText::_('COM_VMREPORTER_UNHIDE_COLUMNS'); ?></button>
				</div>
				
				<div class="vmreporter-toolbar-element last-element hidden-phone hidden-tablet">
					<label for="list-limit" class="sr-only element-invisible"><?php echo JText::_('COM_VMREPORTER_LBL_ITEMS_PER_PAGE'); ?></label>
					<select class="form-select" ng-model="displayPerPage" ng-init="displayPerPage='20'" id="list-limit" class="input-mini">
						<option value="5">5</option>
						<option value="10">10</option>
						<option value="20">20</option>
						<option value="50">50</option>
						<option value="100">100</option>
					</select>
				</div>
			</div>
		</form>
	</div>
	<div class="vmreporter-table-container" ng-init="init()">
		<table id="vmreporter-table" class="table table-striped table-bordered table-hover hide">
			<thead>
				<tr>
					<?php $i = 0; ?>
					<?php foreach($sortFields as $sortField => $sortFieldName) : ?>
						<?php $i++; ?>
						<?php $ng_if = array_key_exists($sortField, $this->order_item_fields) ? ' ng-if="uniqueOnly != \'1\'"' : ''; ?>
						<th<?php echo $ng_if; ?> ng-class="getColumnClass('<?php echo $sortField ?>', item.<?php echo $sortField ?>, 'th')">
							<?php $title = htmlspecialchars('<strong>' . $sortFieldName . '</strong><br/>' . JText::_('COM_VMREPORTER_CLICK_TO_SORT_THIS_COLUMN')); ?>
							<span ng-click="sort('<?php echo $sortField ?>')" class="clickable hasTooltip" title="<?php echo $title ?>"><?php echo $sortFieldName ?>
								<span class="glyphicon sort-icon" ng-show="sortKey=='<?php echo $sortField ?>'" ng-class="{'icon-arrow-up-3':reverse,'icon-arrow-down-3':!reverse}"></span>
							</span>
							<span ng-click="hide('<?php echo $sortField ?>', '<?php echo $i; ?>')" class="clickable btn-hide hasTooltip" title="<?php echo JText::_('COM_VMREPORTER_HIDE_THIS_COLUMN') ?>">&times;</span>
						</th>
					<?php endforeach; ?>
				</tr>
			</thead>
			<tbody>
				<tr dir-paginate="item in items|orderBy:sortKey:reverse|filter:search|itemsPerPage:displayPerPage">
					<?php foreach($sortFields as $sortField => $sortFieldName) : ?>
						<?php $ng_if = array_key_exists($sortField, $this->order_item_fields) ? ' ng-if="uniqueOnly != \'1\'"' : ''; ?>
						<?php if($sortField == 'order_number') : ?>
							<td <?php echo $ng_if; ?> ng-class="getColumnClass('<?php echo $sortField ?>', item.<?php echo $sortField ?>, 'td')"><a href="index.php?option=com_virtuemart&amp;view=orders&amp;task=edit&amp;virtuemart_order_id={{item.virtuemart_order_id}}" target="_blank">{{item.<?php echo $sortField ?>}}</a></td>
						<?php elseif($sortField == 'order_item_name' || $sortField == 'virtuemart_product_id') : ?>
							<td <?php echo $ng_if; ?> ng-class="getColumnClass('<?php echo $sortField ?>', item.<?php echo $sortField ?>, 'td')"><a href="index.php?option=com_virtuemart&amp;view=product&amp;task=edit&amp;virtuemart_product_id={{item.virtuemart_product_id}}" target="_blank">{{item.<?php echo $sortField ?>}}</a></td>
						<?php elseif($sortField == 'username') : ?>
							<td <?php echo $ng_if; ?> ng-class="getColumnClass('<?php echo $sortField ?>', item.<?php echo $sortField ?>, 'td')"><a href="index.php?option=com_users&amp;task=user.edit&ap;id={{item.virtuemart_user_id}}" target="_blank">{{item.<?php echo $sortField ?>}}</a></td>
						<?php elseif($sortField == 'payment_name') : ?>
							<td <?php echo $ng_if; ?> ng-class="getColumnClass('<?php echo $sortField ?>', item.<?php echo $sortField ?>, 'td')"><a href="index.php?option=com_virtuemart&amp;view=paymentmethod&amp;task=edit&amp;cid[]={{item.virtuemart_paymentmethod_id}}" target="_blank">{{item.<?php echo $sortField ?>}}</a></td>
						<?php elseif($sortField == 'shipment_name') : ?>
							<td <?php echo $ng_if; ?> ng-class="getColumnClass('<?php echo $sortField ?>', item.<?php echo $sortField ?>, 'td')"><a href="index.php?option=com_virtuemart&amp;view=shipmentmethod&amp;task=edit&amp;cid[]={{item.virtuemart_shipmentmethod_id}}" target="_blank">{{item.<?php echo $sortField ?>}}</a></td>
						<?php else : ?>
							<td <?php echo $ng_if; ?> ng-class="getColumnClass('<?php echo $sortField ?>', item.<?php echo $sortField ?>, 'td')">{{item.<?php echo $sortField ?>}}</td>
						<?php endif; ?>
					<?php endforeach; ?>
				</tr>
			</tbody>
		</table>
	</div>
	<div class="ng-pagination-container">
		<dir-pagination-controls max-size="10" direction-links="true" boundary-links="true"></dir-pagination-controls>
	</div>
</div>
