<?php
/**
 * @package     Reporter for VirtueMart
 * 
 * @copyright   Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Abhishek Das <info@virtueplanet.com> - https://www.virtueplanet.com
 */

defined('_JEXEC') or die;

class VMReporterViewReport extends JViewLegacy
{
	protected $state;
	protected $params;
	protected $report;
	protected $items;
	protected $report_template;
	protected $data;
	protected $unqiueOrdersOnly;
	protected $order_item_fields;
	protected $currency;
	protected $currency_format;
	protected $start_date;
	protected $end_date;
	
	/**
	 * Display the view
	 */
	public function display($tpl = null)
	{
		$this->state               = $this->get('State');
		$this->report              = $this->get('Report');
		$this->items               = $this->get('Items');
		$this->report_template     = $this->get('ReportTemplate');
		$this->data                = $this->get('Data');
		$this->order_item_fields   = array_filter($this->report_template->order_item_fields);
		$this->unqiueOrdersOnly    = empty($this->order_item_fields);
		$this->params              = $this->state->get('params');
		$this->currency            = CurrencyDisplay::getInstance();
		$this->currency_format     = VMReporterHelper::getCurrencyFormat();
		$this->start_date          = $this->state->get('report.start_date');
		$this->end_date            = $this->state->get('report.end_date');

		if($this->report->id)
		{
			$this->getModel()->markRead();
		}

		// Check for errors.
		if (count($errors = $this->get('Errors')))
		{
			throw new Exception(implode("\n", $errors));
		}
		
		$this->addToolbar();

		parent::display($tpl);
	}
	
	protected function addToolbar()
	{
		JFactory::getApplication()->input->set('hidemainmenu', true);
		
		$user  = JFactory::getUser();

		// Get the toolbar object instance
		$bar = JToolBar::getInstance('toolbar');

		JToolbarHelper::title(JText::_('COM_VMREPORTER_TITLE_REPORT'), 'chart report');
		
		if (version_compare(JVERSION, '4.0.0', 'ge'))
		{
			JToolbarHelper::link(JRoute::_('index.php?option=com_vmreporter&view=reports'), JText::_('COM_VMREPORTER_GO_BACK'), 'arrow-left-4');
		}
		else
		{
			JToolbarHelper::link(JRoute::_('index.php?option=com_vmreporter&view=reports'), JText::_('COM_VMREPORTER_GO_BACK'), 'back');
		}
		
		JToolbarHelper::link(JRoute::_('index.php?option=com_vmreporter&task=report.download&id=' . $this->report->id . '&' . JSession::getFormToken() . '=1'), JText::_('COM_VMREPORTER_DOWNLOAD'), 'download');
	}
	
	/**
	 * Returns an array of fields the table can be sorted by
	 *
	 * @return  array  Array containing the field name to sort by as the key and display text as value
	 */
	protected function getSortFields()
	{
		return $this->get('SortFields');
	}
	
	protected function getColumnSelect($name, $id, $attr = '', $selected = null)
	{
		$options = array();
		
		$options[] = JHtml::_('select.option', '', JText::_('COM_VMREPORTER_ALL_OPTIONS'));
		
		if(!empty($this->columns))
		{
			foreach($this->columns as $value => $text)
			{
				$options[] = JHtml::_('select.option', $value, $text);
			}
		}
		
		$html = JHtml::_('select.genericlist', $options, $name, $attr, 'value', 'text', $selected, $id);
		
		return $html;
	}
	
	protected function getChartSelect($name, $id, $attr = '', $selected = null)
	{
		$options = array();
		$keys    = array(
		             'username', 'order_item_name', 'order_item_sku', 'category_name',
		             'manufacturer_name', 'shipment_name', 'payment_name',
		             'country_3_code', 'shipto_country_3_code', 'virtuemart_product_id'
		           );
		
		if(!empty($this->columns))
		{
			foreach($this->columns as $value => $text)
			{
				if(in_array($value, $keys))
					$options[] = JHtml::_('select.option', $value, $text);
			}
		}
		
		$html = JHtml::_('select.genericlist', $options, $name, $attr, 'value', 'text', $selected, $id);
		
		return $html;
	}
}
