<?php
/**
 * @package     Reporter for VirtueMart
 * 
 * @copyright   Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Abhishek Das <info@virtueplanet.com> - https://www.virtueplanet.com
 */

defined('_JEXEC') or die;

JHtml::addIncludePath(JPATH_COMPONENT . '/helpers/html');

JHtml::_('jquery.framework');
JHtml::_('bootstrap.tooltip');
JHtml::_('behavior.keepalive');
JHtml::_('behavior.formvalidator');

if (version_compare(JVERSION, '4.0.0', 'lt'))
{
	JHtml::_('formbehavior.chosen', 'select');
}

JHtml::_('vmreporter.stylesheet', 'vmreporter/style.css');

$user       = JFactory::getUser();
$listOrder  = $this->escape($this->state->get('list.ordering', ''));
$listDirn   = $this->escape($this->state->get('list.direction', ''));
$date_format = $this->params->get('date_format', 0) ? 'DATE_FORMAT_LC4' : 'DATE_FORMAT_LC5';
?>
<form action="<?php echo JRoute::_('index.php?option=com_vmreporter&view=reports'); ?>" method="post" name="adminForm" id="adminForm">
<?php if (version_compare(JVERSION, '4.0.0', 'lt') && !empty( $this->sidebar)) : ?>
	<div id="j-sidebar-container" class="span2">
		<?php echo $this->sidebar; ?>
	</div>
	<div id="j-main-container" class="span10">
<?php else : ?>
	<div id="j-main-container">
<?php endif; ?>
		<?php
		// Search tools bar
		echo JLayoutHelper::render('joomla.searchtools.default', array('view' => $this));
		?>
		<?php if (empty($this->items)) : ?>
			<div class="alert alert-no-items">
				<?php echo JText::_('JGLOBAL_NO_MATCHING_RESULTS'); ?>
			</div>
		<?php else : ?>
			<table class="table table-striped" id="reportList">
				<thead>
					<tr>
						<th width="1%" class="center text-center">
							<?php echo JHtml::_('grid.checkall'); ?>
						</th>
						<th width="1%" class="nowrap center text-center">
							<?php echo JText::_('COM_VMREPORTER_DOWNLOAD'); ?>
						</th>
						<th>
							<?php echo JHtml::_('searchtools.sort', 'COM_VMREPORTER_REPORTS', 't.name', $listDirn, $listOrder); ?>
						</th>
						<th width="10%" class="nowrap hidden-phone d-none d-sm-table-cell">
							<?php echo JHtml::_('searchtools.sort',  'JAUTHOR', 'u.name', $listDirn, $listOrder); ?>
						</th>
						<th width="10%" class="nowrap">
							<?php echo JHtml::_('searchtools.sort', 'JGLOBAL_CREATED_DATE', 'a.created_time', $listDirn, $listOrder); ?>
						</th>
						<th width="1%" class="nowrap hidden-phone d-none d-md-table-cell">
							<?php echo JHtml::_('searchtools.sort', 'JGRID_HEADING_ID', 'a.id', $listDirn, $listOrder); ?>
						</th>
					</tr>
				</thead>
				<tfoot>
					<tr>
						<td colspan="6">
						</td>
					</tr>
				</tfoot>
				<tbody>
				<?php foreach ($this->items as $i => $item) :
					$item->max_ordering = 0;
					$ordering   = ($listOrder == 'a.ordering');
					?>
					<tr class="row<?php echo $i % 2; ?>">
						<td class="center text-center">
							<?php echo JHtml::_('grid.id', $i, $item->id); ?>
						</td>
						<td class="center text-center">
							<button type="button" onclick="location.href='<?php echo JRoute::_('index.php?option=com_vmreporter&task=report.download&id=' . $item->id . '&' . JSession::getFormToken() . '=1'); ?>';" class="btn btn-outline-secondary btn-micro btn-sm" title="<?php echo $this->escape(JText::_('COM_VMREPORTER_DOWNLOAD')); ?>"><span class="icon-download"></span></button>
						</td>
						<td class="has-context">
							<div class="pull-left break-word">
								<?php if($item->valid) : ?>
									<a class="hasTooltip" href="<?php echo JRoute::_('index.php?option=com_vmreporter&view=report&id=' . (int) $item->id); ?>" title="<?php echo JText::_('COM_VMREPORTER_VIEW_REPORT'); ?>">
										<span><?php echo $this->escape($item->template_name); ?></span>
									</a>
									<?php if(empty($item->users_read) || (is_array($item->users_read) && !in_array($user->get('id'), $item->users_read))) : ?>
										<span class="label label-success label-new p-1 bg-success text-white">NEW</span>
									<?php endif; ?>
								<?php else : ?>
									<span class="icon-smiley-sad-2 text-error report-invalid hasTooltip" title="Invalid Data"></span>&nbsp;<span><?php echo $this->escape($item->template_name); ?></span>
								<?php endif; ?>
								<?php // Show date range ?>
								<div class="date-range">
									<i class="small">
										<span class="muted"><?php echo JText::_('COM_VMREPORTER_FORM_LBL_TEMPLATE_START_DATE') . ': '; ?></span><?php echo JHtml::_('date', $item->start_date, $date_format, null); ?>
										&nbsp;
										<span class="muted"><?php echo JText::_('COM_VMREPORTER_FORM_LBL_TEMPLATE_END_DATE') . ': '; ?></span><?php echo JHtml::_('date', $item->end_date, $date_format, null); ?>
									</i>
								</div>
							</div>
						</td>
						<td class="small hidden-phone d-none d-sm-table-cell">
							<?php if(!empty($item->created_by)) : ?>
								<?php echo $this->escape($item->author); ?>
							<?php else : ?>
								<?php echo JText::_('COM_VMREPORTER_SYSTEM_USER'); ?>
							<?php endif; ?>
						</td>
						<td class="nowrap text-nowrap small">
							<?php echo $item->created_time > 0 ? JHtml::_('date', $item->created_time, JText::_('DATE_FORMAT_LC5')) : '-'; ?>
						</td>
						<td class="hidden-phone small d-none d-md-table-cell">
							<?php echo (int) $item->id; ?>
						</td>
					</tr>
					<?php endforeach; ?>
				</tbody>
			</table>
		<?php endif; ?>
		<?php // Load the batch processing form. ?>
		<?php if ($user->authorise('core.create', 'com_vmreporter')
			&& $user->authorise('core.edit', 'com_vmreporter')
			&& $user->authorise('core.edit.state', 'com_vmreporter')) : ?>
			<?php echo JHtml::_(
				'bootstrap.renderModal',
				'generateModal',
				array(
					'title' => JText::_('COM_VMREPORTER_TITLE_GENERATE_REPORT'),
					'footer' => $this->loadTemplate('generate_footer')
				),
				$this->loadTemplate('generate_body')
			); ?>
		<?php endif; ?>

		<?php echo $this->pagination->getListFooter(); ?>
		
		<input type="hidden" name="task" value="" />
		<input type="hidden" name="boxchecked" value="0" />
		<?php echo JHtml::_('form.token'); ?>
</div>
</form>