<?php
/**
 * @package     Reporter for VirtueMart
 * 
 * @copyright   Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Abhishek Das <info@virtueplanet.com> - https://www.virtueplanet.com
 */

defined('_JEXEC') or die;

/**
 * View class for a list of reports.
 */
class VMReporterViewReports extends JViewLegacy
{
	/**
	 * An array of items
	 *
	 * @var  array
	 */
	protected $items;

	/**
	 * The pagination object
	 *
	 * @var  JPagination
	 */
	protected $pagination;

	/**
	 * The model state
	 *
	 * @var  object
	 */
	protected $state;

	/**
	 * Form object for search filters
	 *
	 * @var  JForm
	 */
	public $filterForm;

	/**
	 * The active search filters
	 *
	 * @var  array
	 */
	public $activeFilters;
	
	public $params;

	/**
	 * The sidebar markup
	 *
	 * @var  string
	 */
	protected $sidebar;

	/**
	 * Display the view
	 */
	public function display($tpl = null)
	{
		$this->state         = $this->get('State');
		$this->items         = $this->get('Items');
		$this->pagination    = $this->get('Pagination');
		$this->filterForm    = $this->get('FilterForm');
		$this->activeFilters = $this->get('ActiveFilters');
		$this->params        = $this->state->get('params');

		// Check for errors.
		if (count($errors = $this->get('Errors')))
		{
			throw new Exception(implode("\n", $errors));
		}
		
		$this->addToolbar();
		
		VMReporterHelper::addSubmenu('reports');

		$this->sidebar = JHtmlSidebar::render();
		
		parent::display($tpl);
	}

	
	protected function addToolbar()
	{
		$user  = JFactory::getUser();
		$canDo = VMReporterHelper::getActions();
		
		// Get the toolbar object instance
		$bar = JToolbar::getInstance('toolbar');

		JToolbarHelper::title(JText::_('COM_VMREPORTER_TITLE_REPORTS'), 'list article');

		// Add a batch button
		if ($user->authorise('core.create', 'com_vmreporter')
			&& $user->authorise('core.edit', 'com_vmreporter')
			&& $user->authorise('core.edit.state', 'com_vmreporter'))
		{
			if (version_compare(JVERSION, '4.0.0', 'ge'))
			{
				$bar->popupButton('Custom')
					->icon('icon-new')
					->text('COM_VMREPORTER_BTN_LABEL_GENERATE')
					->selector('generateModal')
					->listCheck(false);
			}
			else
			{
				// Instantiate a new JLayoutFile instance and render the batch button
				$layout = new JLayoutFile('joomla.toolbar.modal');

				$dhtml = $layout->render(array('selector' => 'generateModal', 'class' => 'btn btn-small btn-success', 'icon' => 'new icon-white', 'text' => JText::_('COM_VMREPORTER_BTN_LABEL_GENERATE')));

				$bar->appendButton('Custom', $dhtml, 'modal');
			}
		}

		if(isset($this->items[0]))
		{
			if ($canDo->get('core.edit.state'))
			{
				JToolbarHelper::deleteList('', 'reports.delete', 'JTOOLBAR_DELETE');
			}
		}

		if ($canDo->get('core.admin'))
		{
			JToolBarHelper::preferences('com_vmreporter');
		}
	}
	
	/**
	 * Returns an array of fields the table can be sorted by
	 *
	 * @return  array  Array containing the field name to sort by as the key and display text as value
	 */
	protected function getSortFields()
	{
		return array(
			'a.ordering'     => JText::_('JGRID_HEADING_ORDERING'),
			'a.state'        => JText::_('JSTATUS'),
			'a.title'        => JText::_('JGLOBAL_TITLE'),
			'category_title' => JText::_('JCATEGORY'),
			'access_level'   => JText::_('JGRID_HEADING_ACCESS'),
			'a.created_by'   => JText::_('JAUTHOR'),
			'language'       => JText::_('JGRID_HEADING_LANGUAGE'),
			'a.created'      => JText::_('JDATE'),
			'a.id'           => JText::_('JGRID_HEADING_ID'),
			'a.featured'     => JText::_('JFEATURED')
		);
	}
}
