<?php
/**
 * @package     Reporter for VirtueMart
 * 
 * @copyright   Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Abhishek Das <info@virtueplanet.com> - https://www.virtueplanet.com
 */

defined('_JEXEC') or die;

JHtml::addIncludePath(JPATH_COMPONENT . '/helpers/html');

JHtml::_('jquery.framework');

if (version_compare(JVERSION, '4.0.0', 'ge'))
{
	$wa = $this->document->getWebAssetManager();
	$wa->useScript('keepalive')
		->useScript('form.validate');
}
else
{
	JHtml::_('behavior.tooltip');
	JHtml::_('formbehavior.chosen', 'select');
	JHtml::_('behavior.formvalidator');
	JHtml::_('behavior.keepalive');
}

JHtml::_('vmreporter.stylesheet', 'vmreporter/style.css');

JFactory::getDocument()->addScriptDeclaration("
	Joomla.submitbutton = function (task) {
		if (task == 'template.cancel') {
			Joomla.submitform(task, document.getElementById('template-form'));
		} else {
			if (task != 'template.cancel' && document.formvalidator.isValid(document.getElementById('template-form'))) {
				Joomla.submitform(task, document.getElementById('template-form'));
			} else {
				alert('" . $this->escape(JText::_('JGLOBAL_VALIDATION_FORM_FAILED')) . "');
			}
		}
	};
");

$tabPrefix = version_compare(JVERSION, '4.0.0', 'ge') ? 'uitab' : 'bootstrap';
?>
<form action="<?php echo JRoute::_('index.php?option=com_vmreporter&view=templatelayout=edit&id=' . (int) $this->item->id); ?>" method="post" name="adminForm" id="template-form" class="form-validate">
	
	<?php echo JLayoutHelper::render('joomla.edit.title_alias', $this); ?>

	<div class="form-horizontal">
	
		<?php echo JHtml::_($tabPrefix . '.startTabSet', 'myTab', array('active' => 'general')); ?>
		
			<?php echo JHtml::_($tabPrefix . '.addTab', 'myTab', 'general', JText::_('COM_VMREPORTER_FIELDSET_GENERAL')); ?>
				<fieldset class="adminform">
					<?php echo $this->form->renderField('id'); ?>
					<?php echo $this->form->renderField('time_field'); ?>
					<?php echo $this->form->renderField('period'); ?>
					<?php echo $this->form->renderField('days'); ?>
					<?php echo $this->form->renderField('start_date'); ?>
					<?php echo $this->form->renderField('end_date'); ?>
					<?php echo $this->form->renderField('download_filename'); ?>
					<h4><?php echo JText::_('COM_VMREPORTER_FORM_LBL_TEMPLATE_FILTER') ?></h4>
					<?php echo $this->form->renderField('products'); ?>
					<?php echo $this->form->renderField('include_child'); ?>
					<?php echo $this->form->renderField('categories'); ?>
					<?php echo $this->form->renderField('manufacturers'); ?>
					<?php echo $this->form->renderField('guests_only'); ?>
					<?php echo $this->form->renderField('users'); ?>
					<?php echo $this->form->renderField('shopper_groups'); ?>
					<?php echo $this->form->renderField('countries'); ?>
					<?php echo $this->form->renderField('st_countries'); ?>
					<?php echo $this->form->renderField('statuses'); ?>
          <?php echo $this->form->renderField('calculation_rules'); ?>
				</fieldset>
			<?php echo JHtml::_($tabPrefix . '.endTab'); ?>
			
			<?php echo JHtml::_($tabPrefix . '.addTab', 'myTab', 'fields', JText::_('COM_VMREPORTER_FIELDSET_FIELDS')); ?>
				<div class="tab-description alert alert-info">
					<span class="icon-info" aria-hidden="true"></span> <?php echo JText::_('COM_VMREPORTER_FORM_LBL_TEMPLATE_FIELDS'); ?>
				</div>
				<?php
				$col = 0;
				$close = false;
				?>
				<?php foreach ($this->form->getFieldsets() as $group => $fieldset) : ?>
					<?php $fields = $this->form->getFieldset($group); ?>
					<?php if (count($fields)) : ?>
						<?php if($col == 0) : ?>
							<div class="<?php echo version_compare(JVERSION, '4.0.0', 'ge') ? 'row' : 'row-fluid'; ?>">
							<?php $close = true; ?>
						<?php endif; ?>
						<?php $col++; ?>
						<div class="<?php echo version_compare(JVERSION, '4.0.0', 'ge') ? 'col-sm-6' : 'span6'; ?>">
							<fieldset id="vmreporter-fieldset-<?php echo $group; ?>" class="vmreporter-fieldset">
								<?php if (isset($fieldset->label) && strlen($legend = trim(JText::_($fieldset->label)))) : ?>
									<legend><?php echo $legend; ?></legend>
								<?php endif; ?>
								<?php if (isset($fieldset->description) && trim($fieldset->description)) : ?>
									<p><?php echo $this->escape(JText::_($fieldset->description)); ?></p>
								<?php endif; ?>
								<?php foreach ($fields as $field) : ?>
									<?php if (!$field->hidden) : ?>
										<div class="checkbox">
											<label for="<?php echo $field->id; ?>">
												<input type="hidden" name="<?php echo $field->name ?>" value="0" />
												<?php if(!$this->item->id && $field->getAttribute('default')) : ?>
													<?php $field->checked = 'true'; ?>
												<?php endif; ?>
												<?php echo $field->input; ?>
												<?php echo $field->title; ?>
											</label>
										</div>
									<?php else : ?>
										<?php echo $field->input; ?>
									<?php endif; ?>
								<?php endforeach; ?>
							</fieldset>
						</div>
						<?php if($col == 2) : ?>
							<?php $col = 0; ?>
							<?php $close = false; ?>
							</div>
						<?php endif; ?>
					<?php endif; ?>
				<?php endforeach; ?>
				<?php if( $close) echo '</div>'; ?>
			<?php echo JHtml::_($tabPrefix . '.endTab'); ?>
			
		<?php echo JHtml::_($tabPrefix . '.endTabSet'); ?>
		
		<input type="hidden" name="task" value="" />
		<?php echo JHtml::_('form.token'); ?>
	</div>
</form>
