<?php
/**
 * @package     Reporter for VirtueMart
 * 
 * @copyright   Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Abhishek Das <info@virtueplanet.com> - https://www.virtueplanet.com
 */

defined('_JEXEC') or die;

JHtml::addIncludePath(JPATH_COMPONENT . '/helpers/html');

JHtml::_('jquery.framework');
JHtml::_('bootstrap.tooltip');

if (version_compare(JVERSION, '4.0.0', 'lt'))
{
	JHtml::_('behavior.multiselect');
	JHtml::_('formbehavior.chosen', 'select');
}

JHtml::_('vmreporter.stylesheet', 'vmreporter/style.css');

$app       = JFactory::getApplication();
$user      = JFactory::getUser();
$userId    = $user->get('id');
$listOrder = str_replace(' ' . $this->state->get('list.direction', ''), '', $this->state->get('list.fullordering', ''));
$listDirn  = $this->escape($this->state->get('list.direction'));
$saveOrder = $listOrder == 'a.id';
?>
<form action="<?php echo JRoute::_('index.php?option=com_vmreporter&view=templates'); ?>" method="post" name="adminForm" id="adminForm">
<?php if (version_compare(JVERSION, '4.0.0', 'lt') && !empty( $this->sidebar)) : ?>
	<div id="j-sidebar-container" class="span2">
		<?php echo $this->sidebar; ?>
	</div>
	<div id="j-main-container" class="span10">
<?php else : ?>
	<div id="j-main-container">
<?php endif; ?>
		<?php
		// Search tools bar
		echo JLayoutHelper::render('joomla.searchtools.default', array('view' => $this));
		?>
		<?php if (empty($this->items)) : ?>
			<div class="alert alert-no-items">
				<?php echo JText::_('JGLOBAL_NO_MATCHING_RESULTS'); ?>
			</div>
		<?php else : ?>
			<table class="table table-striped" id="articleList">
				<thead>
					<tr>
						<th width="1%" class="center text-center">
							<?php echo JHtml::_('grid.checkall'); ?>
						</th>
						<th style="min-width:100px" class="nowrap text-nowrap">
							<?php echo JHtml::_('searchtools.sort', 'JGLOBAL_TITLE', 'a.name', $listDirn, $listOrder); ?>
						</th>
						<th width="1%" class="nowrap text-nowrap">
							<?php echo JHtml::_('searchtools.sort', 'COM_VMREPORTER_MENU_TITLE_REPORTS', 'COUNT(DISTINCT r.id)', $listDirn, $listOrder); ?>
						</th>
						<th width="1%" class="nowrap text-nowrap">
							<?php echo JHtml::_('searchtools.sort', 'COM_VMREPORTER_MENU_TITLE_CRONS', 'COUNT(DISTINCT cr.id)', $listDirn, $listOrder); ?>
						</th>
						<th width="10%" class="nowrap text-nowrap hidden-phone d-none d-sm-table-cell">
							<?php echo JHtml::_('searchtools.sort',  'JGRID_HEADING_CREATED_BY', 'a.created_by', $listDirn, $listOrder); ?>
						</th>
						<th width="10%" class="nowrap text-nowrap hidden-phone d-none d-sm-table-cell">
							<?php echo JHtml::_('searchtools.sort', 'JGLOBAL_CREATED_DATE', 'a.created_on', $listDirn, $listOrder); ?>
						</th>
						<th width="1%" class="nowrap text-nowrap hidden-phone d-none d-sm-table-cell">
							<?php echo JHtml::_('searchtools.sort', 'JGRID_HEADING_ID', 'a.id', $listDirn, $listOrder); ?>
						</th>
					</tr>
				</thead>
				<tfoot>
					<tr>
						<td colspan="7"></td>
					</tr>
				</tfoot>
				<tbody>
				<?php foreach ($this->items as $i => $item) :
					$canCreate  = $user->authorise('core.create',     'com_vmreporter');
					$canEdit    = $user->authorise('core.edit',       'com_vmreporter');
					$canCheckin = $user->authorise('core.manage',     'com_checkin') || $item->checked_out == $userId || $item->checked_out == 0;
					$canEditOwn = $user->authorise('core.edit.own',   'com_vmreporter') && $item->created_by == $userId;
					$canChange  = $user->authorise('core.edit.state', 'com_vmreporter') && $canCheckin;
					?>
					<tr class="row<?php echo $i % 2; ?>">
						<td class="center text-center">
							<?php echo JHtml::_('grid.id', $i, $item->id); ?>
						</td>
						<td class="has-context">
							<div class="pull-left break-word">
								<?php if ($item->checked_out) : ?>
									<?php echo JHtml::_('jgrid.checkedout', $i, $item->editor, $item->checked_out_time, 'templates.', $canCheckin); ?>
								<?php endif; ?>
								<?php if ($canEdit || $canEditOwn) : ?>
									<a class="hasTooltip" href="<?php echo JRoute::_('index.php?option=com_vmreporter&task=template.edit&id=' . $item->id); ?>" title="<?php echo JText::_('JACTION_EDIT'); ?>">
										<?php echo $this->escape($item->name); ?></a>
								<?php else : ?>
									<?php echo $this->escape($item->name); ?>
								<?php endif; ?>
							</div>
						</td>
						<td class="nowrap center text-nowrap text-center">
							<span class="badge badge-info bg-info">
								<?php echo (int) $item->report_count; ?>
							</span>
						</td>
						<td class="nowrap center text-nowrap text-center">
							<span class="badge badge-warning bg-warning">
								<?php echo (int) $item->cron_count; ?>
							</span>
						</td>
						<td class="nowrap hidden-phone small text-nowrap d-none d-sm-table-cell">
								<?php echo $this->escape($item->created_by); ?>
						</td>
						<td class="nowrap hidden-phone small text-nowrap d-none d-sm-table-cell">
							<?php echo $item->created_on > 0 ? JHtml::_('date', $item->created_on, JText::_('DATE_FORMAT_LC5')) : '-'; ?>
						</td>
						<td class="nowrap hidden-phone small text-nowrap d-none d-sm-table-cell">
							<?php echo (int) $item->id; ?>
						</td>
					</tr>
					<?php endforeach; ?>
				</tbody>
			</table>
		<?php endif; ?>

		<?php echo $this->pagination->getListFooter(); ?>

		<input type="hidden" name="task" value="" />
		<input type="hidden" name="boxchecked" value="0" />
		<?php echo JHtml::_('form.token'); ?>
	</div>
</form>