<?php
/**
 * @package     Reporter for VirtueMart
 * 
 * @copyright   Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Abhishek Das <info@virtueplanet.com> - https://www.virtueplanet.com
 */

defined('_JEXEC') or die;

// Access check.
if (!JFactory::getUser()->authorise('core.manage', 'com_vmreporter')) 
{
	throw new JAccessExceptionNotallowed(JText::_('JERROR_ALERTNOAUTHOR'), 403);
}

// Include missing classes and debugging function
require JPATH_COMPONENT . '/include.php';

JLoader::register('VmConfig', JPATH_ADMINISTRATOR . '/components/com_virtuemart/helpers/config.php');

// Check if VirtueMart is installed
if (!class_exists('VmConfig'))
{
	throw new RuntimeException('VirtueMart component is not installed in this site. Exiting Reporter for VirtueMart.', 400);
}

// Load VirtueMart Configuration
VmConfig::loadConfig();

if (!defined('VM_VERSION') || VM_VERSION < 3)
{
	throw new RuntimeException('The installed VirtueMart version is not compatible to this version of Reporter for VirtueMart.', 403);
}

// Load VirtueMart Languages
VmConfig::loadJLang('com_virtuemart');
VmConfig::loadJLang('com_virtuemart', true);
VmConfig::loadJLang('com_virtuemart_orders', true);
VmConfig::loadJLang('com_virtuemart_shoppers', true);

// Register helper class
JLoader::register('VMReporterHelper', JPATH_COMPONENT . '/helpers/vmreporter.php');
JLoader::register('VMReporterGlobal', JPATH_COMPONENT . '/helpers/global.php');
JLoader::register('VMReporterScript', JPATH_COMPONENT . '/helpers/script.php');

// Check system
VMReporterHelper::checkSystem();

// Initialize VMReporter controller
$controller = JControllerLegacy::getInstance('VMReporter');
$controller->execute(JFactory::getApplication()->input->get('task'));
$controller->redirect();
