<?php
/**
 * @package     Reporter for VirtueMart
 * 
 * @copyright   Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Abhishek Das <info@virtueplanet.com> - https://www.virtueplanet.com
 */

defined('_JEXEC') or die();

/**
 * Reporter for VirtueMart Component Package Script
 * 
 * @since   2.2
 */
class com_vmreporterInstallerScript
{
	protected static $tableColumns = array();
	
	/**
	 * Called on installation
	 *
	 * @param   JAdapterInstance  $adapter  The object responsible for running this script
	 *
	 * @return  boolean  True on success
	 */
	public function install($adapter)
	{
		return true;
	}

	/**
	 * Called on update
	 *
	 * @param   JAdapterInstance  $adapter  The object responsible for running this script
	 *
	 * @return  boolean  True on success
	 */
	public function update($adapter)
	{
		$db = JFactory::getDbo();
		
		if (!$this->columnExists('#__vmreporter_templates', 'calculation_rules'))
		{
			$db->setQuery('ALTER TABLE ' . $db->quoteName('#__vmreporter_templates') . ' ADD COLUMN ' . $db->quoteName('calculation_rules') . ' text NOT NULL AFTER ' . $db->quoteName('statuses'));
			$db->execute();
		}
		
		if (!$this->columnExists('#__vmreporter_templates', 'download_filename'))
		{
			$db->setQuery('ALTER TABLE ' . $db->quoteName('#__vmreporter_templates') . ' ADD COLUMN ' . $db->quoteName('download_filename') . ' VARCHAR(255) NOT NULL AFTER ' . $db->quoteName('alias'));
			$db->execute();
		}
		
		if (!$this->columnExists('#__vmreporter_templates', 'time_field'))
		{
			$db->setQuery('ALTER TABLE ' . $db->quoteName('#__vmreporter_templates') . ' ADD COLUMN ' . $db->quoteName('time_field') . ' VARCHAR(15) NOT NULL DEFAULT ' . $db->quote('created_on') . ' AFTER ' . $db->quoteName('st_countries'));
			$db->execute();
		}
		
		if (!$this->columnExists('#__vmreporter_templates', 'include_child'))
		{
			$db->setQuery('ALTER TABLE ' . $db->quoteName('#__vmreporter_templates') . ' ADD COLUMN ' . $db->quoteName('include_child') . 'TINYINT(1) UNSIGNED NOT NULL DEFAULT "0" AFTER ' . $db->quoteName('manufacturers'));
			$db->execute();
		}

		if (!$this->columnExists('#__vmreporter_reports', 'time_field'))
		{
			$db->setQuery('ALTER TABLE ' . $db->quoteName('#__vmreporter_reports') . ' ADD COLUMN ' . $db->quoteName('time_field') . ' VARCHAR(15) NOT NULL DEFAULT ' . $db->quote('created_on') . ' AFTER ' . $db->quoteName('data'));
			$db->execute();
		}

		return true;
	}

	/**
	 * Called before any type of action
	 *
	 * @param     string              $route      Which action is happening (install|uninstall|discover_install)
	 * @param     jadapterinstance    $adapter    The object responsible for running this script
	 *
	 * @return    boolean                         True on success
	 */
	public function preflight($route, $adapter)
	{
		return true;
	}


	/**
	 * Called after any type of action
	 *
	 * @param     string              $route      Which action is happening (install|uninstall|discover_install)
	 * @param     jadapterinstance    $adapter    The object responsible for running this script
	 *
	 * @return    boolean                         True on success
	 */
	public function postflight($route, $adapter)
	{
		return true;
	}
	
	private function columnExists($table, $column)
	{
		if (!isset(self::$tableColumns[$table]))
		{
			$columns = JFactory::getDbo()->getTableColumns($table, false);
			self::$tableColumns[$table] = !empty($columns) ? array_keys($columns) : array();
		}
		
		return in_array($column, self::$tableColumns[$table]);
	}
	
	/**
	* Private method to get the installed Reporter for VirtueMart - System plugin id.
	* 
	* @return mixed(boolean/integer)  false if not found.
	*/
	private function getSystemPlugin()
	{
		$db    = JFactory::getDBO();
		$query = $db->getQuery(true);
		
		$query->select($db->quoteName('extension_id'))
			->from($db->quoteName('#__extensions'))
			->where($db->quoteName('type') . ' = ' . $db->quote('plugin'))
			->where($db->quoteName('element') . ' = ' . $db->quote('vmreporter'))
			->where($db->quoteName('folder') . ' = ' . $db->quote('system'));
			
		try
		{
			$db->setQuery($query);
			$extension_id = $db->loadColumn();
		}
		catch(Exception $e)
		{
			// We can not throw SQL error here.
			return false;
		}
		
		return $extension_id;
	}
}
