<?php
/**
 * @package     Reporter for VirtueMart
 * 
 * @copyright   Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Abhishek Das <info@virtueplanet.com> - https://www.virtueplanet.com
 */

defined('_JEXEC') or die;

class VMReporterShutdownScheduler
{
	private $callbacks; // array to store user callbacks

	public function __construct()
	{
		$this->callbacks = array();
		
		register_shutdown_function(array($this, 'callRegisteredShutdown'));
	}
	
	public function registerShutdownEvent()
	{
		$arguments = func_get_args();

		if (empty($arguments))
		{
			trigger_error('No arguments passed to ' . __FUNCTION__ . ' method', E_USER_ERROR);
			return false;
		}

		if (!is_callable($arguments[1]))
		{
			trigger_error('Invalid callback passed to the ' . __FUNCTION__ . ' method', E_USER_ERROR);
			return false;
		}
		
		if (!is_string($arguments[0]))
		{
			trigger_error('Invalid event name passed to the ' . __FUNCTION__ . ' method', E_USER_ERROR);
			return false;
		}
		
		$eventName = $arguments[0];
		
		unset($arguments[0]);
		
		$this->callbacks[$eventName] = $arguments;
		
		return true;
	}
	
	public function unregisterShutdownEvent($eventName)
	{
		unset($this->callbacks[$eventName]);
	}
	
	public function callRegisteredShutdown()
	{
		foreach ($this->callbacks as $arguments)
		{
			$callback = array_shift($arguments);
			
			call_user_func_array($callback, $arguments);
		}
	}
}
