<?php
/**
 * @package     Reporter for VirtueMart
 * @subpackage  Reporter for VirtueMart - Sales Commission
 * @copyright   Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Abhishek Das <info@virtueplanet.com> - https://www.virtueplanet.com
 */

defined('_JEXEC') or die;

JLoader::register('VmConfig', JPATH_ADMINISTRATOR . '/components/com_virtuemart/helpers/config.php');

class JFormFieldSalescommissions extends JFormField
{
	protected $type = 'Salescommissions';
	
	protected static $groups = null;

	public function getInput()
	{
		VmConfig::loadConfig();
		VmConfig::loadJLang('com_virtuemart');
		VmConfig::loadJLang('com_virtuemart_shoppers', true);
		
		if (self::$groups === null)
		{
			$db    = JFactory::getDBO();
			$query = $db->getQuery(true);
			
			$query->select($db->quoteName('virtuemart_shoppergroup_id') . ' AS value')
				->select($db->quoteName('shopper_group_name') . ' AS text')
				->from($db->quoteName('#__virtuemart_shoppergroups'))
				->where($db->quoteName('published') . ' = 1')
				->order($db->quoteName('virtuemart_shoppergroup_id') . ' ASC');
			
			try
			{
				$db->setQuery($query);
				self::$groups = $db->loadObjectList();
			}
			catch (Exception $e)
			{
				JError::raiseWarning(500, $e->getMessage());
				return false;
			}
		}
		
		$rows = array();
		$values = (array) $this->value;
		
		foreach (self::$groups as $key => $group)
		{
			$value = isset($values[$group->value]) ? $values[$group->value] : 0;
			
			$row = '<td align="center">' . ($key + 1) . '</td>';
			$row .= '<td>' . JText::_($group->text) . '</td>';
			$row .= '<td><input type="number" name="' . $this->name . '[' . $group->value . ']" value="' . preg_replace('#[^0-9\.,]#', '', $value) . '" min="0" step="0.0001" /></td>';
			
			$rows[] = '<tr>' . $row . '</tr>';
		}
		
		$html = '<table class="table table-bordered table-striped table-hover">';
		$html .= '<tr>';
		$html .= '<th width="1%" align="center">#</th>';
		$html .= '<th>Shopper Group</th>';
		$html .= '<th>Commission Rate (%)</th>';
		$html .= '</tr>';
		$html .= implode('', $rows);
		$html .= '</table/>';
		
		return $html;
	}
}
