<?php
/**
 * @package     Reporter for VirtueMart
 * @subpackage  Reporter for VirtueMart - Invoice Number
 * @copyright   Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Abhishek Das <info@virtueplanet.com> - https://www.virtueplanet.com
 */

defined ('_JEXEC') or die;

use Joomla\Registry\Registry;

/**
* Reporter for VirtueMart - Invoice Number Plugin
*/
class plgVmreporterInvoicenumber extends JPlugin
{
	protected $app;
	
	protected $db;
	
	private static $invoiceNumbers = array();
	
	public function onPrepareSortableFields(&$sortableFields, $template_id)
	{
		$key       = isset($sortableFields['order_number']) ? 'order_number' : 'virtuemart_order_id';
		$fieldName = $this->params->get('field_name', 'Invoice Number');
		$lang      = JFactory::getLanguage();
		$string    = strtoupper($fieldName);
		$fieldName = $lang->hasKey($string) ? JText::_($string) : $fieldName;
		
		if (isset($sortableFields[$key]))
		{
			unset($sortableFields['invoice_number']);

			$keys = array_keys($sortableFields);
			$vals = array_values($sortableFields);

			$insertAfter = array_search($key, $keys) + 1;

			$keys2 = array_splice($keys, $insertAfter);
			$vals2 = array_splice($vals, $insertAfter);

			$keys[] = 'invoice_number';
			$vals[] = $fieldName;

			$sortableFields = array_merge(array_combine($keys, $vals), array_combine($keys2, $vals2));
		}
		else
		{
			$sortableFields['invoice_number'] = $fieldName;
		}
	}
	
	public function onPrepareReportItems(&$items, $template_id)
	{
		foreach ($items as &$item)
		{
			if (isset($item['virtuemart_order_id']))
			{
				$invoiceNumbers = $this->getInvoiceNumbers($item['virtuemart_order_id']);
				
				$item['invoice_number'] = !empty($invoiceNumbers) ? implode(', ', $invoiceNumbers) : '';
			}
			else
			{
				$item['invoice_number'] = '';
			}
		}
	}
	
	private function getInvoiceNumbers($order_id)
	{
		if (!isset(self::$invoiceNumbers[$order_id]))
		{
			$query = $this->db->getQuery(true);
			
			$query->select($this->db->quoteName('invoice_number'))
				->from($this->db->quoteName('#__virtuemart_invoices'))
				->where($this->db->quoteName('virtuemart_order_id') . ' = ' . $this->db->quote($order_id));
			
			$this->db->setQuery($query);
			self::$invoiceNumbers[$order_id] = $this->db->loadColumn();
		}
		
		return self::$invoiceNumbers[$order_id];
	}
}
