<?php
/**
 * @package     Reporter for VirtueMart
 * @subpackage  Reporter for VirtueMart - Order Total
 * @copyright   Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Abhishek Das <info@virtueplanet.com> - https://www.virtueplanet.com
 */

defined ('_JEXEC') or die;

/**
* Reporter for VirtueMart - Order Total Plugin
*/
class plgVmreporterOrdertotal extends JPlugin
{
	/**
	* Add order total row to CSV output
	* 
	* @param  array  $items           Report items
	* @param  array  $sortableFields  List of displayable fields
	* 
	* @return void
	*/
	public function onPrepareCsvItems(&$items, $sortableFields, $template_id, &$data)
	{
		if (isset($sortableFields['order_total']) && isset($items[0]) && isset($items[0]['order_total']))
		{
			$blank_row = array_fill_keys(array_keys($items[0]), '');
			$items[]   = $blank_row;
			$total_row = $blank_row;

			reset($sortableFields);
			
			$first_key = key($sortableFields);
			
			reset($sortableFields);
			
			$total_row[$first_key] = $this->params->get('field_name', 'TOTAL');
			$total_row['order_total'] = 0;
			
			$order_ids = array();
			
			foreach ($items as $item)
			{
				if(empty($item['virtuemart_order_id']) || in_array($item['virtuemart_order_id'], $order_ids))
				{
					continue;
				}
				
				$order_ids[] = $item['virtuemart_order_id'];
				
				$total_row['order_total'] += $item['order_total'];
			}
			
			$params = JComponentHelper::getParams('com_vmreporter');
			
			$total_row['order_total'] = VMReporterHelper::formatPrice($total_row['order_total'], $params->get('round_prices', 0));
			
			if ($this->params->get('show_in_mail', 0))
			{
				$mailData = new stdClass;
				$mailData->label = $this->params->get('field_name', 'TOTAL');
				$mailData->value = $total_row['order_total'];
				$mailData->isCurrency = true;
				
				$data['total_order_total'] = $mailData;
			}
			
			$items[] = $total_row;
		}
	}
}
